searchData={"content_type":"text/markdown","items":[{"doc":"high-level module providing a convenient and efficient interface for interacting\nwith the Ethereum blockchain using Elixir.\n\nThis module offers a simple API for common Ethereum operations such as deploying contracts,\nfetching current gas prices, and querying event logs.","ref":"Ethers.html","title":"Ethers","type":"module"},{"doc":"Often you would find yourself executing different actions without dependency. These actions can\nbe combined together in one JSON RPC call. This will save on the number of round trips and\nimproves latency.\n\nBefore continuing, please note that batching JSON RPC requests and using `Ethers.Multicall` are\ntwo different things. As a rule of thumb:\n\n- Use `Ethers.Multicall` if you need to make multiple contract calls and get the result\n  *on the same block*.\n- Use `Ethers.batch/2` if you need to make multiple JSON RPC operations which may or may not run\n  on the same block (or even be related to any specific block e.g. eth_gas_price)\n\n#","ref":"Ethers.html#module-batching-requests","title":"Batching Requests - Ethers","type":"module"},{"doc":"`Ethers.batch/2` supports all operations which the RPC module (`Ethereumex` by default)\nimplements. Although some actions support pre and post processing and some are just forwarded\nto the RPC module.\n\nEvery request passed to `Ethers.batch/2` can be in one of the following formats\n\n- `action_name_atom`: This only works with requests which do not require any additional data.\n  e.g. `:current_gas_price` or `:net_version`.\n- `{action_name_atom, data}`: This works with all other actions which accept input data.\n  e.g. `:call`, `:send` or `:get_logs`.\n- `{action_name_atom, data, overrides_keyword_list}`: Use this to override or add attributes\n  to the action data. This is only accepted for these actions and will through error on others.\n  - `:call`: data should be a Ethers.TxData struct and overrides are accepted.\n  - `:estimate_gas`: data should be a Ethers.TxData struct or a map and overrides are accepted.\n  - `:get_logs`: data should be a Ethers.EventFilter struct and overrides are accepted.\n  - `:send`: data should be a Ethers.TxData struct and overrides are accepted.\n\n\n#","ref":"Ethers.html#module-make-batch-requests","title":"Make batch requests - Ethers","type":"module"},{"doc":"```elixir\nEthers.batch([\n  :current_block_number,\n  :current_gas_price,\n  {:call, Ethers.Contracts.ERC20.name(), to: \"0xc02aaa39b223fe8d0a0e5c4f27ead9083c756cc2\"},\n  {:send, MyContract.ping(), from: \"0xd8dA6BF26964aF9D7eEd9e03E53415D37aA96045\"},\n  {:get_logs, Ethers.Contracts.ERC20.EventFilters.approval(nil, nil)} # <- can have add overrides\n])\n{:ok, [\n  {:ok, 18539069},\n  {:ok, 21221},\n  {:ok, \"Wrapped Ether\"},\n  {:ok, \"0xed67b1aafdc823077166c8ee9da13c6a621d19f4d7a24a80353219c09bdac87f\"},\n  {:ok, [%Ethers.EventFilter{}]}\n]}\n```","ref":"Ethers.html#module-example","title":"Example - Ethers","type":"module"},{"doc":"Combines multiple requests and make a batch json RPC request.\n\nIt returns `{:ok, results}` in case of success or `{:error, reason}` in case of RPC failure.\n\nEach action will have an entry in the results. Each entry is again a tuple and either\n`{:ok, result}` or `{:error, reason}` in case of action failure.\n\nCheckout `Batching Requests` sections in `Ethers` module for more examples.","ref":"Ethers.html#batch/2","title":"Ethers.batch/2","type":"function"},{"doc":"- requests: A list of requests to execute.\n- opts: RPC related options. (No account and block options are accepted in batch)\n\n#","ref":"Ethers.html#batch/2-parameters","title":"Parameters - Ethers.batch/2","type":"function"},{"doc":"An action can be in either of the following formats.\n\n- `{action_name_atom, action_data, action_overrides}`\n- `{action_name_atom, action_data}`\n- `action_name_atom`","ref":"Ethers.html#batch/2-action","title":"Action - Ethers.batch/2","type":"function"},{"doc":"```elixir\nEthers.batch([\n  {:call, WETH.name()},\n  {:call, WETH.symbol(), to: \"[WETH ADDRESS]\"},\n  {:send, WETH.transfer(\"[RECEIVER]\", 1000), from: \"[SENDER]\"},\n  :current_block_number\n])\n{:ok, [ok: \"Weapped Ethereum\", ok: \"WETH\", ok: \"0xhash...\", ok: 182394532]}\n```","ref":"Ethers.html#batch/2-examples","title":"Examples - Ethers.batch/2","type":"function"},{"doc":"Same as `Ethers.batch/2` but raises on error.","ref":"Ethers.html#batch!/2","title":"Ethers.batch!/2","type":"function"},{"doc":"Makes an eth_call to with the given `Ethers.TxData` struct and overrides. It then parses\nthe response using the selector in the TxData struct.","ref":"Ethers.html#call/2","title":"Ethers.call/2","type":"function"},{"doc":"Other than what stated below, any other option given in the overrides keyword list will be merged\nwith the map that the RPC client will receive.\n\n- `:to`: Indicates recepient address. (Contract address in this case)\n- `:block`: The block number or block alias. Defaults to `latest`\n- `:rpc_client`: The RPC Client to use. It should implement ethereum jsonRPC API. default: Ethereumex.HttpClient\n- `:rpc_opts`: Extra options to pass to rpc_client. (Like timeout, Server URL, etc.)","ref":"Ethers.html#call/2-overrides-and-options","title":"Overrides and Options - Ethers.call/2","type":"function"},{"doc":"For contract functions which return a single value (e.g. `function test() returns (uint)`) this\nreturns `{:ok, value}` and for the functions which return multiple values it will return\n`{:ok, [value0, value1]}` (A list).","ref":"Ethers.html#call/2-return-structure","title":"Return structure - Ethers.call/2","type":"function"},{"doc":"```elixir\nEthers.Contract.ERC20.total_supply() |> Ethers.call(to: \"0xa0b...ef6\")\n{:ok, 100000000000000}\n```","ref":"Ethers.html#call/2-examples","title":"Examples - Ethers.call/2","type":"function"},{"doc":"Same as `Ethers.call/2` but raises on error.","ref":"Ethers.html#call!/2","title":"Ethers.call!/2","type":"function"},{"doc":"Returns the current block number of the blockchain.","ref":"Ethers.html#current_block_number/1","title":"Ethers.current_block_number/1","type":"function"},{"doc":"Returns the current gas price from the RPC API","ref":"Ethers.html#current_gas_price/1","title":"Ethers.current_gas_price/1","type":"function"},{"doc":"Deploys a contract to the blockchain.\n\nThis will return the transaction hash for the deployment transaction.\nTo get the address of your deployed contract, use `Ethers.deployed_address/2`.\n\nTo deploy a cotract you must have the binary related to it. It can either be a part of the ABI\nFile you have or as a separate file.","ref":"Ethers.html#deploy/2","title":"Ethers.deploy/2","type":"function"},{"doc":"- contract_module_or_binary: Either the contract module which was already loaded or the compiled\nbinary of the contract. The binary MUST be hex encoded.\n- overrides: A keyword list containing options and overrides.\n  - `:encoded_constructor`: Hex encoded value for constructor parameters. (See `constructor`\n    function of the contract module)\n  - All other options from `Ethers.send/2`","ref":"Ethers.html#deploy/2-parameters","title":"Parameters - Ethers.deploy/2","type":"function"},{"doc":"Returns the address of the deployed contract if the deployment is finished and successful","ref":"Ethers.html#deployed_address/2","title":"Ethers.deployed_address/2","type":"function"},{"doc":"- tx_hash: Hash of the Transaction which created a contract.\n- opts: RPC and account options.","ref":"Ethers.html#deployed_address/2-parameters","title":"Parameters - Ethers.deployed_address/2","type":"function"},{"doc":"Makes an eth_estimate_gas rpc call with the given parameters and overrides.","ref":"Ethers.html#estimate_gas/2","title":"Ethers.estimate_gas/2","type":"function"},{"doc":"- `:to`: Indicates recepient address. (Contract address in this case)\n- `:rpc_client`: The RPC Client to use. It should implement ethereum jsonRPC API. default: Ethereumex.HttpClient\n- `:rpc_opts`: Extra options to pass to rpc_client. (Like timeout, Server URL, etc.)\n\n```elixir\nEthers.Contract.ERC20.transfer(\"0xff0...ea2\", 1000) |> Ethers.estimate_gas(to: \"0xa0b...ef6\")\n{:ok, 12345}\n```","ref":"Ethers.html#estimate_gas/2-overrides-and-options","title":"Overrides and Options - Ethers.estimate_gas/2","type":"function"},{"doc":"Same as `Ethers.estimate_gas/2` but raises on error.","ref":"Ethers.html#estimate_gas!/2","title":"Ethers.estimate_gas!/2","type":"function"},{"doc":"Returns the native token (ETH) balance of an account in wei.","ref":"Ethers.html#get_balance/2","title":"Ethers.get_balance/2","type":"function"},{"doc":"- account: Account which the balance is queried for.\n- overrides:\n  - block: The block you want to query the balance of account in (defaults to `latest`).\n  - rpc_client: The RPC module to use for this request (overrides default).\n  - rpc_opts: Specific RPC options to specify for this request.","ref":"Ethers.html#get_balance/2-parameters","title":"Parameters - Ethers.get_balance/2","type":"function"},{"doc":"Fetches the event logs with the given filter.","ref":"Ethers.html#get_logs/2","title":"Ethers.get_logs/2","type":"function"},{"doc":"- `:address`: Indicates event emitter contract address. (nil means all contracts)\n- `:rpc_client`: The RPC Client to use. It should implement ethereum jsonRPC API. default: Ethereumex.HttpClient\n- `:rpc_opts`: Extra options to pass to rpc_client. (Like timeout, Server URL, etc.)\n- `:fromBlock`: Minimum block number of logs to filter.\n- `:toBlock`: Maximum block number of logs to filter.","ref":"Ethers.html#get_logs/2-overrides-and-options","title":"Overrides and Options - Ethers.get_logs/2","type":"function"},{"doc":"Same as `Ethers.get_logs/2` but raises on error.","ref":"Ethers.html#get_logs!/2","title":"Ethers.get_logs!/2","type":"function"},{"doc":"Returns the native transaction (ETH) by transaction hash.","ref":"Ethers.html#get_transaction/2","title":"Ethers.get_transaction/2","type":"function"},{"doc":"- tx_hash: Transaction hash which the transaction is queried for.\n- overrides:\n  - rpc_client: The RPC module to use for this request (overrides default).\n  - rpc_opts: Specific RPC options to specify for this request.","ref":"Ethers.html#get_transaction/2-parameters","title":"Parameters - Ethers.get_transaction/2","type":"function"},{"doc":"Returns the receipt of a transaction by it's hash.","ref":"Ethers.html#get_transaction_receipt/2","title":"Ethers.get_transaction_receipt/2","type":"function"},{"doc":"- tx_hash: Transaction hash which the transaction receipt is queried for.\n- overrides:\n  - rpc_client: The RPC module to use for this request (overrides default).\n  - rpc_opts: Specific RPC options to specify for this request.","ref":"Ethers.html#get_transaction_receipt/2-parameters","title":"Parameters - Ethers.get_transaction_receipt/2","type":"function"},{"doc":"Returns the current max priority fee per gas from the RPC API","ref":"Ethers.html#max_priority_fee_per_gas/1","title":"Ethers.max_priority_fee_per_gas/1","type":"function"},{"doc":"Makes an eth_send rpc call to with the given data and overrides, Then returns the\ntransaction hash.","ref":"Ethers.html#send/2","title":"Ethers.send/2","type":"function"},{"doc":"Other than what stated below, any other option given in the overrides keyword list will be merged\nwith the map that the RPC client will receive.\n\n#","ref":"Ethers.html#send/2-overrides-and-options","title":"Overrides and Options - Ethers.send/2","type":"function"},{"doc":"- `:from`: The address of the account to sign the transaction with.\n\n#","ref":"Ethers.html#send/2-required-options","title":"Required Options - Ethers.send/2","type":"function"},{"doc":"- `:access_list`: List of storage slots that this transaction accesses (optional)\n- `:chain_id`: Chain id for the transaction (defaults to chain id from RPC server).\n- `:gas_price`: (legacy only) max price willing to pay for each gas.\n- `:gas`: Gas limit for execution of this transaction.\n- `:max_fee_per_gas`: (EIP-1559 only) max fee per gas (defaults to 120% current gas price estimate).\n- `:max_priority_fee_per_gas`: (EIP-1559 only) max priority fee per gas or validator tip. (defaults to zero)\n- `:nonce`: Nonce of the transaction. (defaults to number of transactions of from address)\n- `:rpc_client`: The RPC Client to use. It should implement ethereum jsonRPC API. default: Ethereumex.HttpClient\n- `:rpc_opts`: Extra options to pass to rpc_client. (Like timeout, Server URL, etc.)\n- `:signer`: The signer module to use for signing transaction. Default is nil and will rely on the RPC server for signing.\n- `:signer_opts`: Options for signer module. See your signer docs for more details.\n- `:tx_type`: Transaction type. Either `:eip1559` (default) or `:legacy`.\n- `:to`: Address of the contract or a receiver of this transaction. (required if TxData does not have default_address)\n- `:value`: Ether value to send with the transaction to the receiver (`from => to`).","ref":"Ethers.html#send/2-optional-options","title":"Optional Options - Ethers.send/2","type":"function"},{"doc":"```elixir\nEthers.Contract.ERC20.transfer(\"0xff0...ea2\", 1000) |> Ethers.send(to: \"0xa0b...ef6\")\n{:ok, _tx_hash}\n```","ref":"Ethers.html#send/2-examples","title":"Examples - Ethers.send/2","type":"function"},{"doc":"Same as `Ethers.send/2` but raises on error.","ref":"Ethers.html#send!/2","title":"Ethers.send!/2","type":"function"},{"doc":"Signs a transaction and returns the encoded signed transaction hex.","ref":"Ethers.html#sign_transaction/2","title":"Ethers.sign_transaction/2","type":"function"},{"doc":"Accepts same parameters as `Ethers.send/2`.","ref":"Ethers.html#sign_transaction/2-parameters","title":"Parameters - Ethers.sign_transaction/2","type":"function"},{"doc":"Same as `Ethers.sign_transaction/2` but raises on error.","ref":"Ethers.html#sign_transaction!/2","title":"Ethers.sign_transaction!/2","type":"function"},{"doc":"","ref":"Ethers.html#t:t_batch_request/0","title":"Ethers.t_batch_request/0","type":"type"},{"doc":"Dynamically creates modules for ABIs at compile time.","ref":"Ethers.Contract.html","title":"Ethers.Contract","type":"module"},{"doc":"You can simply create a new module and call `use Ethers.Contract` in it with the desired parameters.\n\n```elixir\n# Using an ABI file\ndefmodule MyProject.Contract do\n  use Ethers.Contract, abi_file: \"path/to/abi.json\"\nend\n\n# Providing a default address\ndefmodule MyProject.Contract do\n  use Ethers.Contract, abi_file: \"path/to/abi.json\", default_address: \"0x1234...999\"\nend\n\n# Using an ABI directly\ndefmodule MyProject.Contract do\n  use Ethers.Contract, abi: [%{\"inputs\" => [], \"type\" => \"constructor\"}, ...]\nend\n```\n\nAfter this, the functions in your contracts should be accessible just by calling\n```elixir\ndata = MyProject.Contract.example_function(...)\n\n# Use data to handle eth_call\nEthers.call(data, to: \"0xADDRESS\", from: \"0xADDRESS\")\n{:ok, [...]}\n```","ref":"Ethers.Contract.html#module-how-to-use","title":"How to use - Ethers.Contract","type":"module"},{"doc":"- `abi`: Used to pass in the decoded (or even encoded json binay) ABI of contract.\n- `abi_file`: Used to pass in the file path to the json ABI of contract.\n- `default_address`: Default contract deployed address to include in the parameters. (Optional)","ref":"Ethers.Contract.html#module-valid-use-options","title":"Valid `use` options - Ethers.Contract","type":"module"},{"doc":"EVM Event struct and helpers","ref":"Ethers.Event.html","title":"Ethers.Event","type":"module"},{"doc":"Decodes a log entry with the given Event function selector and returns an Event struct","ref":"Ethers.Event.html#decode/2","title":"Ethers.Event.decode/2","type":"function"},{"doc":"","ref":"Ethers.Event.html#t:t/0","title":"Ethers.Event.t/0","type":"type"},{"doc":"Event Filter struct and helper functions to work with the event filters","ref":"Ethers.EventFilter.html","title":"Ethers.EventFilter","type":"module"},{"doc":"Holds event filter topics, the event selector and the default address.\n\nCan be passed in to `Ethers.get_logs/2` filter and fetch the logs.","ref":"Ethers.EventFilter.html#t:t/0","title":"Ethers.EventFilter.t/0","type":"type"},{"doc":"This module offers convenient utilities and a user-friendly API for interacting with\n`Multicall3` (for more information, visit https://www.multicall3.com).\n\nThe primary function of this module is to aggregate multiple Ethereum contract calls\ninto a single operation. This aggregated call can be subsequently submitted using `Ethers.call/2`\nor `Ethers.send/2` (If you know what you are doing!).\n\nUpon receiving the response, it can be decoded using `Ethers.Multicall.decode/2` to interpret the\nresults returned by the `Multicall3` contract.","ref":"Ethers.Multicall.html","title":"Ethers.Multicall","type":"module"},{"doc":"```elixir\ncalls = [\n  ContractA.foo(),\n  {ContractB.foo(), to: \"0x...\"},\n]\n\ncalls\n|> Ethers.Multicall.aggregate3() # Or `Ethers.Multicall.aggregate2/1`\n|> Ethers.call!()\n|> Ethers.Multicall.decode(calls)\n```","ref":"Ethers.Multicall.html#module-how-to-use","title":"How to use - Ethers.Multicall","type":"module"},{"doc":"Aggregate calls, returning the executed block number and will revert if any\ncall fails. Returns a `Ethers.TxData` struct which can be passed to `Ethers.call/2`.\n\nFor more information refer to https://github.com/mds1/multicall#batch-contract-reads","ref":"Ethers.Multicall.html#aggregate2/1","title":"Ethers.Multicall.aggregate2/1","type":"function"},{"doc":"- data: A list of `TxData` structs or `{%TxData{...}, options}` tuples. The options can include:\n  - to: Overrides the `default_address` (if any) for the respective function call.","ref":"Ethers.Multicall.html#aggregate2/1-parameters","title":"Parameters - Ethers.Multicall.aggregate2/1","type":"function"},{"doc":"```elixir\nEthers.Multicall.aggregate2([\n  ContractA.foo(), # <-- Assumes `default_address` in ContractA is defined.\n  { ContractB.bar(), to: \"0x...\" }, # <-- ContractB.bar() will call `to`.\n])\n#Ethers.TxData \n```","ref":"Ethers.Multicall.html#aggregate2/1-examples","title":"Examples - Ethers.Multicall.aggregate2/1","type":"function"},{"doc":"Decodes an `aggregate2/2` response from `Ethers.call/2`.","ref":"Ethers.Multicall.html#aggregate2_decode/2","title":"Ethers.Multicall.aggregate2_decode/2","type":"function"},{"doc":"- resps: The response from `Ethers.call/2`.\n- calls: A list of the function calls or signatures passed to `aggregate2/2`.","ref":"Ethers.Multicall.html#aggregate2_decode/2-parameters","title":"Parameters - Ethers.Multicall.aggregate2_decode/2","type":"function"},{"doc":"```elixir\ncalls = [ ContractA.foo(), { ContractB.foo(), to: \"0x...\" } ]\ncalls\n|> Ethers.Multicall.aggregate2()\n|> Ethers.call!()\n|> Ethers.Multicall.aggregate2_decode(calls)\n[ 1337, [ \"bar\", \"baz\" ]]\n```","ref":"Ethers.Multicall.html#aggregate2_decode/2-examples","title":"Examples - Ethers.Multicall.aggregate2_decode/2","type":"function"},{"doc":"Encodes a function call with optional options into a solidity compatible (address,bytes).","ref":"Ethers.Multicall.html#aggregate2_encode_data/1","title":"Ethers.Multicall.aggregate2_encode_data/1","type":"function"},{"doc":"- data:  A `TxData` structs or `{%TxData{...}, options}` tuple. The options can include:\n  - to: Overrides the `default_address` (if any) for the respective function call.","ref":"Ethers.Multicall.html#aggregate2_encode_data/1-parameters","title":"Parameters - Ethers.Multicall.aggregate2_encode_data/1","type":"function"},{"doc":"```elixir\n{ ContractA.foo(), to: \"0x1337...\" } |> aggregate2_encode_data()\n{\"0x1337...\", false, <<...>>}\n\nContractB.bar() |> aggregate2_encode_data()\n{\"0x...\", <<...>>}\n```","ref":"Ethers.Multicall.html#aggregate2_encode_data/1-examples","title":"Examples - Ethers.Multicall.aggregate2_encode_data/1","type":"function"},{"doc":"Aggregates calls, ensuring each returns success if required, and returns a `Ethers.TxData` struct,\nwhich can be passed to `Ethers.call/2`.\n\nFor more details, refer to: https://github.com/mds1/multicall#batch-contract-reads","ref":"Ethers.Multicall.html#aggregate3/1","title":"Ethers.Multicall.aggregate3/1","type":"function"},{"doc":"- `data`: A list of `Ethers.TxData` structs or `{%Ethers.TxData{...}, options}` tuples. The options\ncan include:\n  - `allow_failure`: If set to `false`, the execution will revert. Defaults to `true`.\n  - `to`: Overrides the `default_address` (if any) for the respective function call.","ref":"Ethers.Multicall.html#aggregate3/1-parameters","title":"Parameters - Ethers.Multicall.aggregate3/1","type":"function"},{"doc":"```elixir\nEthers.Multicall.aggregate3([\n  ContractA.foo(), # <-- Assumes `default_address` in ContractA is defined.\n  { ContractB.bar(), to: \"0x...\" }, # <-- ContractB.bar() will call `to`.\n  { ContractC.baz(), allow_failure: false, to: \"0x...\" }\n  # ^^^ -> ContractC.baz() will call `to` and will revert on failure.\n  { ContractD.foo(), allow_failure: false } # <-- ContractD.foo() will revert on failure.\n])\n#Ethers.TxData \n```","ref":"Ethers.Multicall.html#aggregate3/1-examples","title":"Examples - Ethers.Multicall.aggregate3/1","type":"function"},{"doc":"Decodes an `aggregate3/2` response from `Ethers.call/2`.","ref":"Ethers.Multicall.html#aggregate3_decode/2","title":"Ethers.Multicall.aggregate3_decode/2","type":"function"},{"doc":"- resps: The response from `Ethers.call/2`.\n- calls: A list of the function calls or signatures passed to `aggregate3/2`.","ref":"Ethers.Multicall.html#aggregate3_decode/2-parameters","title":"Parameters - Ethers.Multicall.aggregate3_decode/2","type":"function"},{"doc":"```elixir\ncalls = [ ContractA.foo(), { ContractB.foo(), to: \"0x...\" } ]\ncalls\n|> Ethers.Multicall.aggregate3()\n|> Ethers.call!()\n|> Ethers.Multicall.aggregate3_decode(calls)\n[ true: \"bar\", true: \"baz\" ]\n```","ref":"Ethers.Multicall.html#aggregate3_decode/2-examples","title":"Examples - Ethers.Multicall.aggregate3_decode/2","type":"function"},{"doc":"Encodes a function call with optional options into a multicall3 compatible (address,bool,bytes)\ntuple.","ref":"Ethers.Multicall.html#aggregate3_encode_data/1","title":"Ethers.Multicall.aggregate3_encode_data/1","type":"function"},{"doc":"- data: A `Ethers.TxData` struct or `{%Ethers.TxData{...}, options}`. The options can include:\n  - allow_failure: If false the execution will revert. Defaults to true.\n  - to: Overrides the `default_address` (if any) for the respective function call.","ref":"Ethers.Multicall.html#aggregate3_encode_data/1-parameters","title":"Parameters - Ethers.Multicall.aggregate3_encode_data/1","type":"function"},{"doc":"```elixir\n{ ContractA.foo(), allow_failure: false } |> aggregate3_encode_data()\n{\"0x...\", false, <<...>>}\n\nContractB.bar() |> aggregate3_encode_data()\n{\"0x...\", true, <<...>>}\n```","ref":"Ethers.Multicall.html#aggregate3_encode_data/1-examples","title":"Examples - Ethers.Multicall.aggregate3_encode_data/1","type":"function"},{"doc":"Decodes a `Multicall3` response from `Ethers.call/2`.","ref":"Ethers.Multicall.html#decode/2","title":"Ethers.Multicall.decode/2","type":"function"},{"doc":"- resps: List of results returned by aggregate call (The response from `Ethers.call/2`).\n- calls: List of the function calls or signatures passed to `aggregate3/2` or `aggregate2/2`.\n  (used for decoding)","ref":"Ethers.Multicall.html#decode/2-parameters","title":"Parameters - Ethers.Multicall.decode/2","type":"function"},{"doc":"```elixir\ncalls = [ ContractA.foo(), { ContractB.foo(), to: \"0x...\" } ]\ncalls |> Ethers.Multicall.aggregate3() |> Ethers.call!() |> Ethers.Multicall.decode(calls)\n[ true: \"bar\", true: \"baz\" ]\n\ncalls = [ ContractA.foo(), { ContractB.foo(), to: \"0x...\" } ]\ncalls |> Ethers.Multicall.aggregate2() |> Ethers.call!() |> Ethers.Multicall.decode(calls)\n[ 1337, [ \"bar\", \"baz\" ]]\n```","ref":"Ethers.Multicall.html#decode/2-examples","title":"Examples - Ethers.Multicall.decode/2","type":"function"},{"doc":"","ref":"Ethers.Multicall.html#t:aggregate2_options/0","title":"Ethers.Multicall.aggregate2_options/0","type":"type"},{"doc":"","ref":"Ethers.Multicall.html#t:aggregate3_options/0","title":"Ethers.Multicall.aggregate3_options/0","type":"type"},{"doc":"Name Service resolution implementation","ref":"Ethers.NameService.html","title":"Ethers.NameService","type":"module"},{"doc":"Implementation of namehash function in Elixir.\n\nSee https://docs.ens.domains/contract-api-reference/name-processing","ref":"Ethers.NameService.html#name_hash/1","title":"Ethers.NameService.name_hash/1","type":"function"},{"doc":"iex> Ethers.NameService.name_hash(\"foo.eth\")\n    Ethers.Utils.hex_decode!(\"0xde9b09fd7c5f901e23a3f19fecc54828e9c848539801e86591bd9801b019f84f\")\n\n    iex> Ethers.NameService.name_hash(\"alisina.eth\")\n    Ethers.Utils.hex_decode!(\"0x1b557b3901bef3a986febf001c3b19370b34064b130d49ea967bf150f6d23dfe\")","ref":"Ethers.NameService.html#name_hash/1-examples","title":"Examples - Ethers.NameService.name_hash/1","type":"function"},{"doc":"Resolves a name on blockchain.","ref":"Ethers.NameService.html#resolve/2","title":"Ethers.NameService.resolve/2","type":"function"},{"doc":"- name: Domain name to resolve. (Example: `foo.eth`)\n- opts: Resolve options.\n  - to: Resolver contract address. Defaults to ENS\n  - Accepts all other Execution options from `Ethers.call/2`.","ref":"Ethers.NameService.html#resolve/2-parameters","title":"Parameters - Ethers.NameService.resolve/2","type":"function"},{"doc":"```elixir\nEthers.NameService.resolve(\"vitalik.eth\")\n{:ok, \"0xd8da6bf26964af9d7eed9e03e53415d37aa96045\"}\n```","ref":"Ethers.NameService.html#resolve/2-examples","title":"Examples - Ethers.NameService.resolve/2","type":"function"},{"doc":"Same as `resolve/2` but raises on errors.","ref":"Ethers.NameService.html#resolve!/2","title":"Ethers.NameService.resolve!/2","type":"function"},{"doc":"```elixir\nEthers.NameService.resolve!(\"vitalik.eth\")\n\"0xd8da6bf26964af9d7eed9e03e53415d37aa96045\"\n```","ref":"Ethers.NameService.html#resolve!/2-examples","title":"Examples - Ethers.NameService.resolve!/2","type":"function"},{"doc":"Transaction struct and helper functions","ref":"Ethers.Transaction.html","title":"Ethers.Transaction","type":"module"},{"doc":"","ref":"Ethers.Transaction.html#calculate_y_parity_or_v/2","title":"Ethers.Transaction.calculate_y_parity_or_v/2","type":"function"},{"doc":"Decodes a transaction struct values in a new map.","ref":"Ethers.Transaction.html#decode_values/1","title":"Ethers.Transaction.decode_values/1","type":"function"},{"doc":"","ref":"Ethers.Transaction.html#encode/1","title":"Ethers.Transaction.encode/1","type":"function"},{"doc":"","ref":"Ethers.Transaction.html#fill_with_defaults/2","title":"Ethers.Transaction.fill_with_defaults/2","type":"function"},{"doc":"","ref":"Ethers.Transaction.html#from_map/1","title":"Ethers.Transaction.from_map/1","type":"function"},{"doc":"","ref":"Ethers.Transaction.html#new/2","title":"Ethers.Transaction.new/2","type":"function"},{"doc":"","ref":"Ethers.Transaction.html#to_map/1","title":"Ethers.Transaction.to_map/1","type":"function"},{"doc":"","ref":"Ethers.Transaction.html#t:t/0","title":"Ethers.Transaction.t/0","type":"type"},{"doc":"","ref":"Ethers.Transaction.html#t:t_transaction_type/0","title":"Ethers.Transaction.t_transaction_type/0","type":"type"},{"doc":"Transaction struct to hold information about the ABI selector, encoded data\nand the target `to` address.","ref":"Ethers.TxData.html","title":"Ethers.TxData","type":"module"},{"doc":"Holds transaction data, the function selector and the default `to` address.\n\nCan be passed in to `Ethers.call/2` or `Ethers.send/2` to execute.","ref":"Ethers.TxData.html#t:t/0","title":"Ethers.TxData.t/0","type":"type"},{"doc":"EVM types and compound type definitions","ref":"Ethers.Types.html","title":"Ethers.Types","type":"module"},{"doc":"Returns the default value in the given type if supported.","ref":"Ethers.Types.html#default/1","title":"Ethers.Types.default/1","type":"function"},{"doc":"iex> Ethers.Types.default(:address)\n    \"0x0000000000000000000000000000000000000000\"\n\n    iex> Ethers.Types.default({:int, 32})\n    0\n\n    iex> Ethers.Types.default({:uint, 8})\n    0\n\n    iex> Ethers.Types.default({:int, 128})\n    0\n\n    iex> Ethers.Types.default(:string)\n    \"\"\n\n    iex> Ethers.Types.default(:bytes)\n    \"\"\n\n    iex> Ethers.Types.default({:bytes, 8})\n    <<0, 0, 0, 0, 0, 0, 0, 0>>","ref":"Ethers.Types.html#default/1-examples","title":"Examples - Ethers.Types.default/1","type":"function"},{"doc":"Checks if a given data matches a given solidity type","ref":"Ethers.Types.html#matches_type?/2","title":"Ethers.Types.matches_type?/2","type":"function"},{"doc":"iex> Ethers.Types.matches_type?(false, :bool)\n    true\n\n    iex> Ethers.Types.matches_type?(200, {:uint, 8})\n    true\n\n    iex> Ethers.Types.matches_type?(400, {:uint, 8})\n    false\n\n    iex> Ethers.Types.matches_type?(\"0xdAC17F958D2ee523a2206206994597C13D831ec7\", :address)\n    true","ref":"Ethers.Types.html#matches_type?/2-examples","title":"Examples - Ethers.Types.matches_type?/2","type":"function"},{"doc":"Returns the maximum possible value in the given type if supported.","ref":"Ethers.Types.html#max/1","title":"Ethers.Types.max/1","type":"function"},{"doc":"iex> Ethers.Types.max({:uint, 8})\n    255\n\n    iex> Ethers.Types.max({:int, 8})\n    127\n\n    iex> Ethers.Types.max({:uint, 16})\n    65535\n\n    iex> Ethers.Types.max({:int, 16})\n    32767\n\n    iex> Ethers.Types.max({:uint, 128})\n    340282366920938463463374607431768211455\n\n    iex> Ethers.Types.max({:int, 128})\n    170141183460469231731687303715884105727","ref":"Ethers.Types.html#max/1-examples","title":"Examples - Ethers.Types.max/1","type":"function"},{"doc":"Returns the minimum possible value in the given type if supported.","ref":"Ethers.Types.html#min/1","title":"Ethers.Types.min/1","type":"function"},{"doc":"iex> Ethers.Types.min({:uint, 8})\n    0\n\n    iex> Ethers.Types.min({:int, 8})\n    -128\n\n    iex> Ethers.Types.min({:uint, 16})\n    0\n\n    iex> Ethers.Types.min({:int, 16})\n    -32768\n\n    iex> Ethers.Types.min({:int, 24})\n    -8388608\n\n    iex> Ethers.Types.min({:int, 128})\n    -170141183460469231731687303715884105728","ref":"Ethers.Types.html#min/1-examples","title":"Examples - Ethers.Types.min/1","type":"function"},{"doc":"Converts EVM data types to typespecs for documentation","ref":"Ethers.Types.html#to_elixir_type/1","title":"Ethers.Types.to_elixir_type/1","type":"function"},{"doc":"Validates and creates typed values to use with functions or events.\n\nTyped values are useful when there are multiple overloads of same function or event and you need\nto specify one of them to be used.\n\nAlso raises with ArgumentError in case value does not match the given type.","ref":"Ethers.Types.html#typed/2","title":"Ethers.Types.typed/2","type":"function"},{"doc":"iex> Ethers.Types.typed({:uint, 256}, 5)\n    {:typed, {:uint, 256}, 5}\n\n    iex> Ethers.Types.typed(:bytes, <<0, 1, 2>>)\n    {:typed, :bytes, <<0, 1, 2>>}","ref":"Ethers.Types.html#typed/2-examples","title":"Examples - Ethers.Types.typed/2","type":"function"},{"doc":"Ethereum address in its hex format with 0x or in its binary format","ref":"Ethers.Types.html#t:t_address/0","title":"Ethers.Types.t_address/0","type":"type"},{"doc":"- `\"0xdAC17F958D2ee523a2206206994597C13D831ec7\"`\n- `<<218, 193, 127, 149, 141, 46, 229, 35, 162, 32, 98, 6, 153, 69, 151, 193, 61, 131, 30, 199>>`","ref":"Ethers.Types.html#t:t_address/0-examples","title":"Examples - Ethers.Types.t_address/0","type":"type"},{"doc":"","ref":"Ethers.Types.html#t:t_bitsizes/0","title":"Ethers.Types.t_bitsizes/0","type":"type"},{"doc":"","ref":"Ethers.Types.html#t:t_bytesizes/0","title":"Ethers.Types.t_bytesizes/0","type":"type"},{"doc":"","ref":"Ethers.Types.html#t:t_evm_types/0","title":"Ethers.Types.t_evm_types/0","type":"type"},{"doc":"keccak hash in its hex format with 0x","ref":"Ethers.Types.html#t:t_hash/0","title":"Ethers.Types.t_hash/0","type":"type"},{"doc":"- `\"0xd4288c8e733eb71a39fe2e8dd4912ce54d8d26d9874f30309b26b4b071260422\"`","ref":"Ethers.Types.html#t:t_hash/0-examples","title":"Examples - Ethers.Types.t_hash/0","type":"type"},{"doc":"Public key either in its uncompressed format (64 bytes MAY BE prefixed with 0x04) or its\ncompressed format (32 bytes MUST BE prefixed with 0x02 or 0x03)\n\nIt can be hex encoded but only with 0x prefix.\n\nCompressed public key MUST have a prefix.","ref":"Ethers.Types.html#t:t_pub_key/0","title":"Ethers.Types.t_pub_key/0","type":"type"},{"doc":"Utilities for interacting with ethereum blockchain","ref":"Ethers.Utils.html","title":"Ethers.Utils","type":"module"},{"doc":"Returns the nearest block number to a given date and time.","ref":"Ethers.Utils.html#date_to_block_number/3","title":"Ethers.Utils.date_to_block_number/3","type":"function"},{"doc":"- date_or_date_time: Can be a `Date`, `DateTime` or an integer unix timestamp.\n- ref_block_number: A block number of reference which is closer to the target block.\n  Can make search time faster if given. (Defaults to current block number)\n- opts: Optional extra options.\n  - acceptable_drift: Can be set to override the default acceptable_drift of\n    120 seconds. This value can be reduced for more accurate results.\n  - sample_size: Can be set to override the default sample_size of 5000 blocks.","ref":"Ethers.Utils.html#date_to_block_number/3-parameters","title":"Parameters - Ethers.Utils.date_to_block_number/3","type":"function"},{"doc":"Convert WEI to ETH","ref":"Ethers.Utils.html#from_wei/1","title":"Ethers.Utils.from_wei/1","type":"function"},{"doc":"iex> Ethers.Utils.from_wei(1000000000000000000)\n    1.0\n\n    iex> Ethers.Utils.from_wei(3140000000000000000)\n    3.14\n\n    iex> Ethers.Utils.from_wei(-10000000000000000000)\n    -10.0","ref":"Ethers.Utils.html#from_wei/1-examples","title":"Examples - Ethers.Utils.from_wei/1","type":"function"},{"doc":"Returns the timestamp for a given block number.\n\nThe block_number parameter can be a non negative integer or the hex encoded value of that integer.\n(The hex encoding *must* start with 0x prefix)","ref":"Ethers.Utils.html#get_block_timestamp/2","title":"Ethers.Utils.get_block_timestamp/2","type":"function"},{"doc":"Decode from hex with (or without) 0x prefix.","ref":"Ethers.Utils.html#hex_decode/1","title":"Ethers.Utils.hex_decode/1","type":"function"},{"doc":"iex> Ethers.Utils.hex_decode(\"0x6574686572735f6578\")\n    {:ok, \"ethers_ex\"}\n\n    iex> Ethers.Utils.hex_decode(\"6574686572735f6578\")\n    {:ok, \"ethers_ex\"}\n\n    iex> Ethers.Utils.hex_decode(\"0x686\")\n    {:ok, <<6, 134>>}","ref":"Ethers.Utils.html#hex_decode/1-examples","title":"Examples - Ethers.Utils.hex_decode/1","type":"function"},{"doc":"Same as `hex_decode/1` but raises on error","ref":"Ethers.Utils.html#hex_decode!/1","title":"Ethers.Utils.hex_decode!/1","type":"function"},{"doc":"iex> Ethers.Utils.hex_decode!(\"0x6574686572735f6578\")\n    \"ethers_ex\"\n\n    iex> Ethers.Utils.hex_decode!(\"6574686572735f6578\")\n    \"ethers_ex\"","ref":"Ethers.Utils.html#hex_decode!/1-examples","title":"Examples - Ethers.Utils.hex_decode!/1","type":"function"},{"doc":"Encode to hex with 0x prefix.","ref":"Ethers.Utils.html#hex_encode/2","title":"Ethers.Utils.hex_encode/2","type":"function"},{"doc":"iex> Ethers.Utils.hex_encode(\"ethers_ex\")\n    \"0x6574686572735f6578\"","ref":"Ethers.Utils.html#hex_encode/2-examples","title":"Examples - Ethers.Utils.hex_encode/2","type":"function"},{"doc":"Converts a hexadecimal integer to integer form","ref":"Ethers.Utils.html#hex_to_integer/1","title":"Ethers.Utils.hex_to_integer/1","type":"function"},{"doc":"iex> Ethers.Utils.hex_to_integer(\"0x11111\")\n    {:ok, 69905}","ref":"Ethers.Utils.html#hex_to_integer/1-examples","title":"Examples - Ethers.Utils.hex_to_integer/1","type":"function"},{"doc":"Same as `hex_to_integer/1` but raises on error","ref":"Ethers.Utils.html#hex_to_integer!/1","title":"Ethers.Utils.hex_to_integer!/1","type":"function"},{"doc":"iex> Ethers.Utils.hex_to_integer!(\"0x11111\")\n    69905","ref":"Ethers.Utils.html#hex_to_integer!/1-examples","title":"Examples - Ethers.Utils.hex_to_integer!/1","type":"function"},{"doc":"Reverse of `prepare_arg/2`","ref":"Ethers.Utils.html#human_arg/2","title":"Ethers.Utils.human_arg/2","type":"function"},{"doc":"iex> Ethers.Utils.human_arg(<<192, 42, 170, 57, 178, 35, 254, 141, 10, 14, 92, 79, 39,\n    ...> 234, 217, 8, 60, 117, 108, 194>>, :address)\n    \"0xc02aaa39b223fe8d0a0e5c4f27ead9083c756cc2\"\n\n    iex> Ethers.Utils.human_arg(\"0xc02aaa39b223fe8d0a0e5c4f27ead9083c756cc2\", :address)\n    \"0xc02aaa39b223fe8d0a0e5c4f27ead9083c756cc2\"","ref":"Ethers.Utils.html#human_arg/2-examples","title":"Examples - Ethers.Utils.human_arg/2","type":"function"},{"doc":"Converts integer to its hexadecimal form","ref":"Ethers.Utils.html#integer_to_hex/1","title":"Ethers.Utils.integer_to_hex/1","type":"function"},{"doc":"iex> Ethers.Utils.integer_to_hex(69905)\n    \"0x11111\"","ref":"Ethers.Utils.html#integer_to_hex/1-examples","title":"Examples - Ethers.Utils.integer_to_hex/1","type":"function"},{"doc":"Adds gas limit estimation to the parameters if not already exists\n\nIf option `mult` is given, a gas limit multiplied by `mult` divided by 1000 will be used.\nDefault for `mult` is 100. (1%)","ref":"Ethers.Utils.html#maybe_add_gas_limit/2","title":"Ethers.Utils.maybe_add_gas_limit/2","type":"function"},{"doc":"Converts human readable argument to the form required for ABI encoding.\n\nFor example the addresses in Ethereum are represented by hex strings in human readable format\nbut are in 160-bit binaries in ABI form.","ref":"Ethers.Utils.html#prepare_arg/2","title":"Ethers.Utils.prepare_arg/2","type":"function"},{"doc":"iex> Ethers.Utils.prepare_arg(\"0xc02aaa39b223fe8d0a0e5c4f27ead9083c756cc2\", :address)\n    <<192, 42, 170, 57, 178, 35, 254, 141, 10, 14, 92, 79, 39, 234, 217, 8, 60, 117, 108, 194>>","ref":"Ethers.Utils.html#prepare_arg/2-examples","title":"Examples - Ethers.Utils.prepare_arg/2","type":"function"},{"doc":"Calculates address of a given public key. Public key can be in compressed or decompressed format\neither with or without prefix. It can also be hex encoded.","ref":"Ethers.Utils.html#public_key_to_address/1","title":"Ethers.Utils.public_key_to_address/1","type":"function"},{"doc":"iex> Utils.public_key_to_address(\"0x04e68acfc0253a10620dff706b0a1b1f1f5833ea3beb3bde2250d5f271f3563606672ebc45e0b7ea2e816ecb70ca03137b1c9476eec63d4632e990020b7b6fba39\")\n    \"0x90F8bf6A479f320ead074411a4B0e7944Ea8c9C1\"\n\n    iex> Utils.public_key_to_address(\"0x03e68acfc0253a10620dff706b0a1b1f1f5833ea3beb3bde2250d5f271f3563606\")\n    \"0x90F8bf6A479f320ead074411a4B0e7944Ea8c9C1\"","ref":"Ethers.Utils.html#public_key_to_address/1-examples","title":"Examples - Ethers.Utils.public_key_to_address/1","type":"function"},{"doc":"Will convert an upper or lowercase Ethereum address to a checksum address.","ref":"Ethers.Utils.html#to_checksum_address/1","title":"Ethers.Utils.to_checksum_address/1","type":"function"},{"doc":"iex> Ethers.Utils.to_checksum_address(\"0xc1912fee45d61c87cc5ea59dae31190fffff232d\")\n    \"0xc1912fEE45d61C87Cc5EA59DaE31190FFFFf232d\"\n\n    iex> Ethers.Utils.to_checksum_address(\"0XC1912FEE45D61C87CC5EA59DAE31190FFFFF232D\")\n    \"0xc1912fEE45d61C87Cc5EA59DaE31190FFFFf232d\"","ref":"Ethers.Utils.html#to_checksum_address/1-examples","title":"Examples - Ethers.Utils.to_checksum_address/1","type":"function"},{"doc":"Converts ETH to WEI","ref":"Ethers.Utils.html#to_wei/1","title":"Ethers.Utils.to_wei/1","type":"function"},{"doc":"iex> Ethers.Utils.to_wei(1)\n    1000000000000000000\n\n    iex> Ethers.Utils.to_wei(3.14)\n    3140000000000000000\n\n    iex> Ethers.Utils.to_wei(0)\n    0\n\n    iex> Ethers.Utils.to_wei(-10)\n    -10000000000000000000","ref":"Ethers.Utils.html#to_wei/1-examples","title":"Examples - Ethers.Utils.to_wei/1","type":"function"},{"doc":"Checks the checksum of a given address. Will also return false on non-checksum addresses.","ref":"Ethers.Utils.html#valid_checksum_address?/1","title":"Ethers.Utils.valid_checksum_address?/1","type":"function"},{"doc":"iex> Ethers.Utils.valid_checksum_address?(\"0xc1912fEE45d61C87Cc5EA59DaE31190FFFFf232d\")\n    true\n\n    iex> Ethers.Utils.valid_checksum_address?(\"0xc1912fee45d61C87Cc5EA59DaE31190FFFFf232d\")\n    false","ref":"Ethers.Utils.html#valid_checksum_address?/1-examples","title":"Examples - Ethers.Utils.valid_checksum_address?/1","type":"function"},{"doc":"Ethereum Name Service (ENS) Contract","ref":"Ethers.Contracts.ENS.html","title":"Ethers.Contracts.ENS","type":"module"},{"doc":"Default address of the contract. Returns `nil` if not specified.\n\nTo specify a default address see `Ethers.Contract`","ref":"Ethers.Contracts.ENS.html#__default_address__/0","title":"Ethers.Contracts.ENS.__default_address__/0","type":"function"},{"doc":"Prepares contract constructor values for deployment.\n\nTo deploy a contracts use `Ethers.deploy/2` and pass the result of this function as\n`:encoded_constructor` option.","ref":"Ethers.Contracts.ENS.html#constructor/1","title":"Ethers.Contracts.ENS.constructor/1","type":"function"},{"doc":"- _old: `:address`","ref":"Ethers.Contracts.ENS.html#constructor/1-parameters","title":"Parameters - Ethers.Contracts.ENS.constructor/1","type":"function"},{"doc":"Prepares `isApprovedForAll(address owner, address operator)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","ref":"Ethers.Contracts.ENS.html#is_approved_for_all/2","title":"Ethers.Contracts.ENS.is_approved_for_all/2","type":"function"},{"doc":"- owner: `:address`\n - operator: `:address`","ref":"Ethers.Contracts.ENS.html#is_approved_for_all/2-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ENS.is_approved_for_all/2","type":"function"},{"doc":"- `:bool`","ref":"Ethers.Contracts.ENS.html#is_approved_for_all/2-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.is_approved_for_all/2","type":"function"},{"doc":"Prepares `old()` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","ref":"Ethers.Contracts.ENS.html#old/0","title":"Ethers.Contracts.ENS.old/0","type":"function"},{"doc":"- `:address`","ref":"Ethers.Contracts.ENS.html#old/0-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.old/0","type":"function"},{"doc":"Prepares `owner(bytes32 node)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","ref":"Ethers.Contracts.ENS.html#owner/1","title":"Ethers.Contracts.ENS.owner/1","type":"function"},{"doc":"- node: `{:bytes, 32}`","ref":"Ethers.Contracts.ENS.html#owner/1-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ENS.owner/1","type":"function"},{"doc":"- `:address`","ref":"Ethers.Contracts.ENS.html#owner/1-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.owner/1","type":"function"},{"doc":"Prepares `recordExists(bytes32 node)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","ref":"Ethers.Contracts.ENS.html#record_exists/1","title":"Ethers.Contracts.ENS.record_exists/1","type":"function"},{"doc":"- node: `{:bytes, 32}`","ref":"Ethers.Contracts.ENS.html#record_exists/1-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ENS.record_exists/1","type":"function"},{"doc":"- `:bool`","ref":"Ethers.Contracts.ENS.html#record_exists/1-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.record_exists/1","type":"function"},{"doc":"Prepares `resolver(bytes32 node)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","ref":"Ethers.Contracts.ENS.html#resolver/1","title":"Ethers.Contracts.ENS.resolver/1","type":"function"},{"doc":"- node: `{:bytes, 32}`","ref":"Ethers.Contracts.ENS.html#resolver/1-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ENS.resolver/1","type":"function"},{"doc":"- `:address`","ref":"Ethers.Contracts.ENS.html#resolver/1-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.resolver/1","type":"function"},{"doc":"Prepares `setApprovalForAll(address operator, bool approved)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","ref":"Ethers.Contracts.ENS.html#set_approval_for_all/2","title":"Ethers.Contracts.ENS.set_approval_for_all/2","type":"function"},{"doc":"- operator: `:address`\n - approved: `:bool`","ref":"Ethers.Contracts.ENS.html#set_approval_for_all/2-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ENS.set_approval_for_all/2","type":"function"},{"doc":"This function does not return any values!","ref":"Ethers.Contracts.ENS.html#set_approval_for_all/2-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.set_approval_for_all/2","type":"function"},{"doc":"Prepares `setOwner(bytes32 node, address owner)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","ref":"Ethers.Contracts.ENS.html#set_owner/2","title":"Ethers.Contracts.ENS.set_owner/2","type":"function"},{"doc":"- node: `{:bytes, 32}`\n - owner: `:address`","ref":"Ethers.Contracts.ENS.html#set_owner/2-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ENS.set_owner/2","type":"function"},{"doc":"This function does not return any values!","ref":"Ethers.Contracts.ENS.html#set_owner/2-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.set_owner/2","type":"function"},{"doc":"Prepares `setRecord(bytes32 node, address owner, address resolver, uint64 ttl)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","ref":"Ethers.Contracts.ENS.html#set_record/4","title":"Ethers.Contracts.ENS.set_record/4","type":"function"},{"doc":"- node: `{:bytes, 32}`\n - owner: `:address`\n - resolver: `:address`\n - ttl: `{:uint, 64}`","ref":"Ethers.Contracts.ENS.html#set_record/4-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ENS.set_record/4","type":"function"},{"doc":"This function does not return any values!","ref":"Ethers.Contracts.ENS.html#set_record/4-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.set_record/4","type":"function"},{"doc":"Prepares `setResolver(bytes32 node, address resolver)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","ref":"Ethers.Contracts.ENS.html#set_resolver/2","title":"Ethers.Contracts.ENS.set_resolver/2","type":"function"},{"doc":"- node: `{:bytes, 32}`\n - resolver: `:address`","ref":"Ethers.Contracts.ENS.html#set_resolver/2-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ENS.set_resolver/2","type":"function"},{"doc":"This function does not return any values!","ref":"Ethers.Contracts.ENS.html#set_resolver/2-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.set_resolver/2","type":"function"},{"doc":"Prepares `setSubnodeOwner(bytes32 node, bytes32 label, address owner)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","ref":"Ethers.Contracts.ENS.html#set_subnode_owner/3","title":"Ethers.Contracts.ENS.set_subnode_owner/3","type":"function"},{"doc":"- node: `{:bytes, 32}`\n - label: `{:bytes, 32}`\n - owner: `:address`","ref":"Ethers.Contracts.ENS.html#set_subnode_owner/3-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ENS.set_subnode_owner/3","type":"function"},{"doc":"- `{:bytes, 32}`","ref":"Ethers.Contracts.ENS.html#set_subnode_owner/3-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.set_subnode_owner/3","type":"function"},{"doc":"Prepares `setSubnodeRecord(bytes32 node, bytes32 label, address owner, address resolver, uint64 ttl)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","ref":"Ethers.Contracts.ENS.html#set_subnode_record/5","title":"Ethers.Contracts.ENS.set_subnode_record/5","type":"function"},{"doc":"- node: `{:bytes, 32}`\n - label: `{:bytes, 32}`\n - owner: `:address`\n - resolver: `:address`\n - ttl: `{:uint, 64}`","ref":"Ethers.Contracts.ENS.html#set_subnode_record/5-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ENS.set_subnode_record/5","type":"function"},{"doc":"This function does not return any values!","ref":"Ethers.Contracts.ENS.html#set_subnode_record/5-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.set_subnode_record/5","type":"function"},{"doc":"Prepares `setTTL(bytes32 node, uint64 ttl)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","ref":"Ethers.Contracts.ENS.html#set_ttl/2","title":"Ethers.Contracts.ENS.set_ttl/2","type":"function"},{"doc":"- node: `{:bytes, 32}`\n - ttl: `{:uint, 64}`","ref":"Ethers.Contracts.ENS.html#set_ttl/2-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ENS.set_ttl/2","type":"function"},{"doc":"This function does not return any values!","ref":"Ethers.Contracts.ENS.html#set_ttl/2-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.set_ttl/2","type":"function"},{"doc":"Prepares `ttl(bytes32 node)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","ref":"Ethers.Contracts.ENS.html#ttl/1","title":"Ethers.Contracts.ENS.ttl/1","type":"function"},{"doc":"- node: `{:bytes, 32}`","ref":"Ethers.Contracts.ENS.html#ttl/1-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ENS.ttl/1","type":"function"},{"doc":"- `{:uint, 64}`","ref":"Ethers.Contracts.ENS.html#ttl/1-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.ttl/1","type":"function"},{"doc":"Ethereum Name Service (ENS) Resolver Contract","ref":"Ethers.Contracts.ENS.Resolver.html","title":"Ethers.Contracts.ENS.Resolver","type":"module"},{"doc":"Default address of the contract. Returns `nil` if not specified.\n\nTo specify a default address see `Ethers.Contract`","ref":"Ethers.Contracts.ENS.Resolver.html#__default_address__/0","title":"Ethers.Contracts.ENS.Resolver.__default_address__/0","type":"function"},{"doc":"Prepares `ABI(bytes32 node, uint256 contentTypes)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","ref":"Ethers.Contracts.ENS.Resolver.html#abi/2","title":"Ethers.Contracts.ENS.Resolver.abi/2","type":"function"},{"doc":"- node: `{:bytes, 32}`\n - contentTypes: `{:uint, 256}`","ref":"Ethers.Contracts.ENS.Resolver.html#abi/2-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ENS.Resolver.abi/2","type":"function"},{"doc":"- `{:uint, 256}`\n - `:bytes`","ref":"Ethers.Contracts.ENS.Resolver.html#abi/2-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.Resolver.abi/2","type":"function"},{"doc":"Prepares `addr(bytes32 node)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","ref":"Ethers.Contracts.ENS.Resolver.html#addr/1","title":"Ethers.Contracts.ENS.Resolver.addr/1","type":"function"},{"doc":"- node: `{:bytes, 32}`","ref":"Ethers.Contracts.ENS.Resolver.html#addr/1-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ENS.Resolver.addr/1","type":"function"},{"doc":"- `:address`","ref":"Ethers.Contracts.ENS.Resolver.html#addr/1-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.Resolver.addr/1","type":"function"},{"doc":"Prepares `addr(bytes32 node, uint256 coinType)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","ref":"Ethers.Contracts.ENS.Resolver.html#addr/2","title":"Ethers.Contracts.ENS.Resolver.addr/2","type":"function"},{"doc":"- node: `{:bytes, 32}`\n - coinType: `{:uint, 256}`","ref":"Ethers.Contracts.ENS.Resolver.html#addr/2-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ENS.Resolver.addr/2","type":"function"},{"doc":"- `:bytes`","ref":"Ethers.Contracts.ENS.Resolver.html#addr/2-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.Resolver.addr/2","type":"function"},{"doc":"Prepares `authorisations(bytes32, address, address)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","ref":"Ethers.Contracts.ENS.Resolver.html#authorisations/3","title":"Ethers.Contracts.ENS.Resolver.authorisations/3","type":"function"},{"doc":"- `{:bytes, 32}`\n - `:address`\n - `:address`","ref":"Ethers.Contracts.ENS.Resolver.html#authorisations/3-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ENS.Resolver.authorisations/3","type":"function"},{"doc":"- `:bool`","ref":"Ethers.Contracts.ENS.Resolver.html#authorisations/3-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.Resolver.authorisations/3","type":"function"},{"doc":"Prepares `clearDNSZone(bytes32 node)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","ref":"Ethers.Contracts.ENS.Resolver.html#clear_dns_zone/1","title":"Ethers.Contracts.ENS.Resolver.clear_dns_zone/1","type":"function"},{"doc":"- node: `{:bytes, 32}`","ref":"Ethers.Contracts.ENS.Resolver.html#clear_dns_zone/1-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ENS.Resolver.clear_dns_zone/1","type":"function"},{"doc":"This function does not return any values!","ref":"Ethers.Contracts.ENS.Resolver.html#clear_dns_zone/1-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.Resolver.clear_dns_zone/1","type":"function"},{"doc":"Prepares contract constructor values for deployment.\n\nTo deploy a contracts use `Ethers.deploy/2` and pass the result of this function as\n`:encoded_constructor` option.","ref":"Ethers.Contracts.ENS.Resolver.html#constructor/1","title":"Ethers.Contracts.ENS.Resolver.constructor/1","type":"function"},{"doc":"- _ens: `:address`","ref":"Ethers.Contracts.ENS.Resolver.html#constructor/1-parameters","title":"Parameters - Ethers.Contracts.ENS.Resolver.constructor/1","type":"function"},{"doc":"Prepares `contenthash(bytes32 node)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","ref":"Ethers.Contracts.ENS.Resolver.html#contenthash/1","title":"Ethers.Contracts.ENS.Resolver.contenthash/1","type":"function"},{"doc":"- node: `{:bytes, 32}`","ref":"Ethers.Contracts.ENS.Resolver.html#contenthash/1-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ENS.Resolver.contenthash/1","type":"function"},{"doc":"- `:bytes`","ref":"Ethers.Contracts.ENS.Resolver.html#contenthash/1-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.Resolver.contenthash/1","type":"function"},{"doc":"Prepares `dnsRecord(bytes32 node, bytes32 name, uint16 resource)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","ref":"Ethers.Contracts.ENS.Resolver.html#dns_record/3","title":"Ethers.Contracts.ENS.Resolver.dns_record/3","type":"function"},{"doc":"- node: `{:bytes, 32}`\n - name: `{:bytes, 32}`\n - resource: `{:uint, 16}`","ref":"Ethers.Contracts.ENS.Resolver.html#dns_record/3-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ENS.Resolver.dns_record/3","type":"function"},{"doc":"- `:bytes`","ref":"Ethers.Contracts.ENS.Resolver.html#dns_record/3-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.Resolver.dns_record/3","type":"function"},{"doc":"Prepares `hasDNSRecords(bytes32 node, bytes32 name)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","ref":"Ethers.Contracts.ENS.Resolver.html#has_dns_records/2","title":"Ethers.Contracts.ENS.Resolver.has_dns_records/2","type":"function"},{"doc":"- node: `{:bytes, 32}`\n - name: `{:bytes, 32}`","ref":"Ethers.Contracts.ENS.Resolver.html#has_dns_records/2-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ENS.Resolver.has_dns_records/2","type":"function"},{"doc":"- `:bool`","ref":"Ethers.Contracts.ENS.Resolver.html#has_dns_records/2-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.Resolver.has_dns_records/2","type":"function"},{"doc":"Prepares `interfaceImplementer(bytes32 node, bytes4 interfaceID)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","ref":"Ethers.Contracts.ENS.Resolver.html#interface_implementer/2","title":"Ethers.Contracts.ENS.Resolver.interface_implementer/2","type":"function"},{"doc":"- node: `{:bytes, 32}`\n - interfaceID: `{:bytes, 4}`","ref":"Ethers.Contracts.ENS.Resolver.html#interface_implementer/2-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ENS.Resolver.interface_implementer/2","type":"function"},{"doc":"- `:address`","ref":"Ethers.Contracts.ENS.Resolver.html#interface_implementer/2-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.Resolver.interface_implementer/2","type":"function"},{"doc":"Prepares `multicall(bytes[] data)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","ref":"Ethers.Contracts.ENS.Resolver.html#multicall/1","title":"Ethers.Contracts.ENS.Resolver.multicall/1","type":"function"},{"doc":"- data: `{:array, :bytes}`","ref":"Ethers.Contracts.ENS.Resolver.html#multicall/1-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ENS.Resolver.multicall/1","type":"function"},{"doc":"- results: `{:array, :bytes}`","ref":"Ethers.Contracts.ENS.Resolver.html#multicall/1-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.Resolver.multicall/1","type":"function"},{"doc":"Prepares `name(bytes32 node)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","ref":"Ethers.Contracts.ENS.Resolver.html#name/1","title":"Ethers.Contracts.ENS.Resolver.name/1","type":"function"},{"doc":"- node: `{:bytes, 32}`","ref":"Ethers.Contracts.ENS.Resolver.html#name/1-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ENS.Resolver.name/1","type":"function"},{"doc":"- `:string`","ref":"Ethers.Contracts.ENS.Resolver.html#name/1-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.Resolver.name/1","type":"function"},{"doc":"Prepares `pubkey(bytes32 node)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","ref":"Ethers.Contracts.ENS.Resolver.html#pubkey/1","title":"Ethers.Contracts.ENS.Resolver.pubkey/1","type":"function"},{"doc":"- node: `{:bytes, 32}`","ref":"Ethers.Contracts.ENS.Resolver.html#pubkey/1-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ENS.Resolver.pubkey/1","type":"function"},{"doc":"- x: `{:bytes, 32}`\n - y: `{:bytes, 32}`","ref":"Ethers.Contracts.ENS.Resolver.html#pubkey/1-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.Resolver.pubkey/1","type":"function"},{"doc":"Prepares `setABI(bytes32 node, uint256 contentType, bytes data)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","ref":"Ethers.Contracts.ENS.Resolver.html#set_abi/3","title":"Ethers.Contracts.ENS.Resolver.set_abi/3","type":"function"},{"doc":"- node: `{:bytes, 32}`\n - contentType: `{:uint, 256}`\n - data: `:bytes`","ref":"Ethers.Contracts.ENS.Resolver.html#set_abi/3-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ENS.Resolver.set_abi/3","type":"function"},{"doc":"This function does not return any values!","ref":"Ethers.Contracts.ENS.Resolver.html#set_abi/3-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.Resolver.set_abi/3","type":"function"},{"doc":"Prepares `setAddr(bytes32 node, address a)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","ref":"Ethers.Contracts.ENS.Resolver.html#set_addr/2","title":"Ethers.Contracts.ENS.Resolver.set_addr/2","type":"function"},{"doc":"- node: `{:bytes, 32}`\n - a: `:address`","ref":"Ethers.Contracts.ENS.Resolver.html#set_addr/2-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ENS.Resolver.set_addr/2","type":"function"},{"doc":"This function does not return any values!","ref":"Ethers.Contracts.ENS.Resolver.html#set_addr/2-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.Resolver.set_addr/2","type":"function"},{"doc":"Prepares `setAddr(bytes32 node, uint256 coinType, bytes a)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","ref":"Ethers.Contracts.ENS.Resolver.html#set_addr/3","title":"Ethers.Contracts.ENS.Resolver.set_addr/3","type":"function"},{"doc":"- node: `{:bytes, 32}`\n - coinType: `{:uint, 256}`\n - a: `:bytes`","ref":"Ethers.Contracts.ENS.Resolver.html#set_addr/3-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ENS.Resolver.set_addr/3","type":"function"},{"doc":"This function does not return any values!","ref":"Ethers.Contracts.ENS.Resolver.html#set_addr/3-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.Resolver.set_addr/3","type":"function"},{"doc":"Prepares `setAuthorisation(bytes32 node, address target, bool isAuthorised)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","ref":"Ethers.Contracts.ENS.Resolver.html#set_authorisation/3","title":"Ethers.Contracts.ENS.Resolver.set_authorisation/3","type":"function"},{"doc":"- node: `{:bytes, 32}`\n - target: `:address`\n - isAuthorised: `:bool`","ref":"Ethers.Contracts.ENS.Resolver.html#set_authorisation/3-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ENS.Resolver.set_authorisation/3","type":"function"},{"doc":"This function does not return any values!","ref":"Ethers.Contracts.ENS.Resolver.html#set_authorisation/3-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.Resolver.set_authorisation/3","type":"function"},{"doc":"Prepares `setContenthash(bytes32 node, bytes hash)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","ref":"Ethers.Contracts.ENS.Resolver.html#set_contenthash/2","title":"Ethers.Contracts.ENS.Resolver.set_contenthash/2","type":"function"},{"doc":"- node: `{:bytes, 32}`\n - hash: `:bytes`","ref":"Ethers.Contracts.ENS.Resolver.html#set_contenthash/2-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ENS.Resolver.set_contenthash/2","type":"function"},{"doc":"This function does not return any values!","ref":"Ethers.Contracts.ENS.Resolver.html#set_contenthash/2-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.Resolver.set_contenthash/2","type":"function"},{"doc":"Prepares `setDNSRecords(bytes32 node, bytes data)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","ref":"Ethers.Contracts.ENS.Resolver.html#set_dns_records/2","title":"Ethers.Contracts.ENS.Resolver.set_dns_records/2","type":"function"},{"doc":"- node: `{:bytes, 32}`\n - data: `:bytes`","ref":"Ethers.Contracts.ENS.Resolver.html#set_dns_records/2-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ENS.Resolver.set_dns_records/2","type":"function"},{"doc":"This function does not return any values!","ref":"Ethers.Contracts.ENS.Resolver.html#set_dns_records/2-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.Resolver.set_dns_records/2","type":"function"},{"doc":"Prepares `setInterface(bytes32 node, bytes4 interfaceID, address implementer)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","ref":"Ethers.Contracts.ENS.Resolver.html#set_interface/3","title":"Ethers.Contracts.ENS.Resolver.set_interface/3","type":"function"},{"doc":"- node: `{:bytes, 32}`\n - interfaceID: `{:bytes, 4}`\n - implementer: `:address`","ref":"Ethers.Contracts.ENS.Resolver.html#set_interface/3-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ENS.Resolver.set_interface/3","type":"function"},{"doc":"This function does not return any values!","ref":"Ethers.Contracts.ENS.Resolver.html#set_interface/3-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.Resolver.set_interface/3","type":"function"},{"doc":"Prepares `setName(bytes32 node, string name)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","ref":"Ethers.Contracts.ENS.Resolver.html#set_name/2","title":"Ethers.Contracts.ENS.Resolver.set_name/2","type":"function"},{"doc":"- node: `{:bytes, 32}`\n - name: `:string`","ref":"Ethers.Contracts.ENS.Resolver.html#set_name/2-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ENS.Resolver.set_name/2","type":"function"},{"doc":"This function does not return any values!","ref":"Ethers.Contracts.ENS.Resolver.html#set_name/2-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.Resolver.set_name/2","type":"function"},{"doc":"Prepares `setPubkey(bytes32 node, bytes32 x, bytes32 y)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","ref":"Ethers.Contracts.ENS.Resolver.html#set_pubkey/3","title":"Ethers.Contracts.ENS.Resolver.set_pubkey/3","type":"function"},{"doc":"- node: `{:bytes, 32}`\n - x: `{:bytes, 32}`\n - y: `{:bytes, 32}`","ref":"Ethers.Contracts.ENS.Resolver.html#set_pubkey/3-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ENS.Resolver.set_pubkey/3","type":"function"},{"doc":"This function does not return any values!","ref":"Ethers.Contracts.ENS.Resolver.html#set_pubkey/3-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.Resolver.set_pubkey/3","type":"function"},{"doc":"Prepares `setText(bytes32 node, string key, string value)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","ref":"Ethers.Contracts.ENS.Resolver.html#set_text/3","title":"Ethers.Contracts.ENS.Resolver.set_text/3","type":"function"},{"doc":"- node: `{:bytes, 32}`\n - key: `:string`\n - value: `:string`","ref":"Ethers.Contracts.ENS.Resolver.html#set_text/3-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ENS.Resolver.set_text/3","type":"function"},{"doc":"This function does not return any values!","ref":"Ethers.Contracts.ENS.Resolver.html#set_text/3-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.Resolver.set_text/3","type":"function"},{"doc":"Prepares `supportsInterface(bytes4 interfaceID)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `pure`","ref":"Ethers.Contracts.ENS.Resolver.html#supports_interface/1","title":"Ethers.Contracts.ENS.Resolver.supports_interface/1","type":"function"},{"doc":"- interfaceID: `{:bytes, 4}`","ref":"Ethers.Contracts.ENS.Resolver.html#supports_interface/1-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ENS.Resolver.supports_interface/1","type":"function"},{"doc":"- `:bool`","ref":"Ethers.Contracts.ENS.Resolver.html#supports_interface/1-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.Resolver.supports_interface/1","type":"function"},{"doc":"Prepares `text(bytes32 node, string key)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","ref":"Ethers.Contracts.ENS.Resolver.html#text/2","title":"Ethers.Contracts.ENS.Resolver.text/2","type":"function"},{"doc":"- node: `{:bytes, 32}`\n - key: `:string`","ref":"Ethers.Contracts.ENS.Resolver.html#text/2-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ENS.Resolver.text/2","type":"function"},{"doc":"- `:string`","ref":"Ethers.Contracts.ENS.Resolver.html#text/2-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.Resolver.text/2","type":"function"},{"doc":"ERC1155 token interface\n\nMore info: https://ethereum.org/en/developers/docs/standards/tokens/erc-1155/","ref":"Ethers.Contracts.ERC1155.html","title":"Ethers.Contracts.ERC1155","type":"module"},{"doc":"Default address of the contract. Returns `nil` if not specified.\n\nTo specify a default address see `Ethers.Contract`","ref":"Ethers.Contracts.ERC1155.html#__default_address__/0","title":"Ethers.Contracts.ERC1155.__default_address__/0","type":"function"},{"doc":"Prepares `balanceOf(address account, uint256 id)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","ref":"Ethers.Contracts.ERC1155.html#balance_of/2","title":"Ethers.Contracts.ERC1155.balance_of/2","type":"function"},{"doc":"- account: `:address`\n - id: `{:uint, 256}`","ref":"Ethers.Contracts.ERC1155.html#balance_of/2-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ERC1155.balance_of/2","type":"function"},{"doc":"- `{:uint, 256}`","ref":"Ethers.Contracts.ERC1155.html#balance_of/2-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC1155.balance_of/2","type":"function"},{"doc":"Prepares `balanceOfBatch(address[] accounts, uint256[] ids)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","ref":"Ethers.Contracts.ERC1155.html#balance_of_batch/2","title":"Ethers.Contracts.ERC1155.balance_of_batch/2","type":"function"},{"doc":"- accounts: `{:array, :address}`\n - ids: `{:array, {:uint, 256}}`","ref":"Ethers.Contracts.ERC1155.html#balance_of_batch/2-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ERC1155.balance_of_batch/2","type":"function"},{"doc":"- `{:array, {:uint, 256}}`","ref":"Ethers.Contracts.ERC1155.html#balance_of_batch/2-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC1155.balance_of_batch/2","type":"function"},{"doc":"Prepares contract constructor values for deployment.\n\nTo deploy a contracts use `Ethers.deploy/2` and pass the result of this function as\n`:encoded_constructor` option.","ref":"Ethers.Contracts.ERC1155.html#constructor/0","title":"Ethers.Contracts.ERC1155.constructor/0","type":"function"},{"doc":"","ref":"Ethers.Contracts.ERC1155.html#constructor/0-parameters","title":"Parameters - Ethers.Contracts.ERC1155.constructor/0","type":"function"},{"doc":"Prepares `isApprovedForAll(address account, address operator)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","ref":"Ethers.Contracts.ERC1155.html#is_approved_for_all/2","title":"Ethers.Contracts.ERC1155.is_approved_for_all/2","type":"function"},{"doc":"- account: `:address`\n - operator: `:address`","ref":"Ethers.Contracts.ERC1155.html#is_approved_for_all/2-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ERC1155.is_approved_for_all/2","type":"function"},{"doc":"- `:bool`","ref":"Ethers.Contracts.ERC1155.html#is_approved_for_all/2-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC1155.is_approved_for_all/2","type":"function"},{"doc":"Prepares `safeBatchTransferFrom(address from, address to, uint256[] ids, uint256[] values, bytes data)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","ref":"Ethers.Contracts.ERC1155.html#safe_batch_transfer_from/5","title":"Ethers.Contracts.ERC1155.safe_batch_transfer_from/5","type":"function"},{"doc":"- from: `:address`\n - to: `:address`\n - ids: `{:array, {:uint, 256}}`\n - values: `{:array, {:uint, 256}}`\n - data: `:bytes`","ref":"Ethers.Contracts.ERC1155.html#safe_batch_transfer_from/5-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ERC1155.safe_batch_transfer_from/5","type":"function"},{"doc":"This function does not return any values!","ref":"Ethers.Contracts.ERC1155.html#safe_batch_transfer_from/5-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC1155.safe_batch_transfer_from/5","type":"function"},{"doc":"Prepares `safeTransferFrom(address from, address to, uint256 id, uint256 value, bytes data)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","ref":"Ethers.Contracts.ERC1155.html#safe_transfer_from/5","title":"Ethers.Contracts.ERC1155.safe_transfer_from/5","type":"function"},{"doc":"- from: `:address`\n - to: `:address`\n - id: `{:uint, 256}`\n - value: `{:uint, 256}`\n - data: `:bytes`","ref":"Ethers.Contracts.ERC1155.html#safe_transfer_from/5-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ERC1155.safe_transfer_from/5","type":"function"},{"doc":"This function does not return any values!","ref":"Ethers.Contracts.ERC1155.html#safe_transfer_from/5-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC1155.safe_transfer_from/5","type":"function"},{"doc":"Prepares `setApprovalForAll(address operator, bool approved)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","ref":"Ethers.Contracts.ERC1155.html#set_approval_for_all/2","title":"Ethers.Contracts.ERC1155.set_approval_for_all/2","type":"function"},{"doc":"- operator: `:address`\n - approved: `:bool`","ref":"Ethers.Contracts.ERC1155.html#set_approval_for_all/2-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ERC1155.set_approval_for_all/2","type":"function"},{"doc":"This function does not return any values!","ref":"Ethers.Contracts.ERC1155.html#set_approval_for_all/2-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC1155.set_approval_for_all/2","type":"function"},{"doc":"Prepares `supportsInterface(bytes4 interfaceId)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","ref":"Ethers.Contracts.ERC1155.html#supports_interface/1","title":"Ethers.Contracts.ERC1155.supports_interface/1","type":"function"},{"doc":"- interfaceId: `{:bytes, 4}`","ref":"Ethers.Contracts.ERC1155.html#supports_interface/1-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ERC1155.supports_interface/1","type":"function"},{"doc":"- `:bool`","ref":"Ethers.Contracts.ERC1155.html#supports_interface/1-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC1155.supports_interface/1","type":"function"},{"doc":"Prepares `uri(uint256)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","ref":"Ethers.Contracts.ERC1155.html#uri/1","title":"Ethers.Contracts.ERC1155.uri/1","type":"function"},{"doc":"- `{:uint, 256}`","ref":"Ethers.Contracts.ERC1155.html#uri/1-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ERC1155.uri/1","type":"function"},{"doc":"- `:string`","ref":"Ethers.Contracts.ERC1155.html#uri/1-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC1155.uri/1","type":"function"},{"doc":"ERC20 token interface\n\nMore info: https://ethereum.org/en/developers/docs/standards/tokens/erc-20/","ref":"Ethers.Contracts.ERC20.html","title":"Ethers.Contracts.ERC20","type":"module"},{"doc":"Default address of the contract. Returns `nil` if not specified.\n\nTo specify a default address see `Ethers.Contract`","ref":"Ethers.Contracts.ERC20.html#__default_address__/0","title":"Ethers.Contracts.ERC20.__default_address__/0","type":"function"},{"doc":"Prepares `allowance(address owner, address spender)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","ref":"Ethers.Contracts.ERC20.html#allowance/2","title":"Ethers.Contracts.ERC20.allowance/2","type":"function"},{"doc":"- owner: `:address`\n - spender: `:address`","ref":"Ethers.Contracts.ERC20.html#allowance/2-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ERC20.allowance/2","type":"function"},{"doc":"- `{:uint, 256}`","ref":"Ethers.Contracts.ERC20.html#allowance/2-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC20.allowance/2","type":"function"},{"doc":"Prepares `approve(address spender, uint256 value)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","ref":"Ethers.Contracts.ERC20.html#approve/2","title":"Ethers.Contracts.ERC20.approve/2","type":"function"},{"doc":"- spender: `:address`\n - value: `{:uint, 256}`","ref":"Ethers.Contracts.ERC20.html#approve/2-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ERC20.approve/2","type":"function"},{"doc":"- `:bool`","ref":"Ethers.Contracts.ERC20.html#approve/2-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC20.approve/2","type":"function"},{"doc":"Prepares `balanceOf(address account)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","ref":"Ethers.Contracts.ERC20.html#balance_of/1","title":"Ethers.Contracts.ERC20.balance_of/1","type":"function"},{"doc":"- account: `:address`","ref":"Ethers.Contracts.ERC20.html#balance_of/1-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ERC20.balance_of/1","type":"function"},{"doc":"- `{:uint, 256}`","ref":"Ethers.Contracts.ERC20.html#balance_of/1-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC20.balance_of/1","type":"function"},{"doc":"Prepares contract constructor values for deployment.\n\nTo deploy a contracts use `Ethers.deploy/2` and pass the result of this function as\n`:encoded_constructor` option.","ref":"Ethers.Contracts.ERC20.html#constructor/0","title":"Ethers.Contracts.ERC20.constructor/0","type":"function"},{"doc":"","ref":"Ethers.Contracts.ERC20.html#constructor/0-parameters","title":"Parameters - Ethers.Contracts.ERC20.constructor/0","type":"function"},{"doc":"Prepares `decimals()` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","ref":"Ethers.Contracts.ERC20.html#decimals/0","title":"Ethers.Contracts.ERC20.decimals/0","type":"function"},{"doc":"- `{:uint, 8}`","ref":"Ethers.Contracts.ERC20.html#decimals/0-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC20.decimals/0","type":"function"},{"doc":"Prepares `name()` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","ref":"Ethers.Contracts.ERC20.html#name/0","title":"Ethers.Contracts.ERC20.name/0","type":"function"},{"doc":"- `:string`","ref":"Ethers.Contracts.ERC20.html#name/0-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC20.name/0","type":"function"},{"doc":"Prepares `symbol()` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","ref":"Ethers.Contracts.ERC20.html#symbol/0","title":"Ethers.Contracts.ERC20.symbol/0","type":"function"},{"doc":"- `:string`","ref":"Ethers.Contracts.ERC20.html#symbol/0-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC20.symbol/0","type":"function"},{"doc":"Prepares `totalSupply()` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","ref":"Ethers.Contracts.ERC20.html#total_supply/0","title":"Ethers.Contracts.ERC20.total_supply/0","type":"function"},{"doc":"- `{:uint, 256}`","ref":"Ethers.Contracts.ERC20.html#total_supply/0-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC20.total_supply/0","type":"function"},{"doc":"Prepares `transfer(address to, uint256 value)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","ref":"Ethers.Contracts.ERC20.html#transfer/2","title":"Ethers.Contracts.ERC20.transfer/2","type":"function"},{"doc":"- to: `:address`\n - value: `{:uint, 256}`","ref":"Ethers.Contracts.ERC20.html#transfer/2-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ERC20.transfer/2","type":"function"},{"doc":"- `:bool`","ref":"Ethers.Contracts.ERC20.html#transfer/2-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC20.transfer/2","type":"function"},{"doc":"Prepares `transferFrom(address from, address to, uint256 value)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","ref":"Ethers.Contracts.ERC20.html#transfer_from/3","title":"Ethers.Contracts.ERC20.transfer_from/3","type":"function"},{"doc":"- from: `:address`\n - to: `:address`\n - value: `{:uint, 256}`","ref":"Ethers.Contracts.ERC20.html#transfer_from/3-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ERC20.transfer_from/3","type":"function"},{"doc":"- `:bool`","ref":"Ethers.Contracts.ERC20.html#transfer_from/3-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC20.transfer_from/3","type":"function"},{"doc":"ERC721 token interface\n\nMore info: https://ethereum.org/en/developers/docs/standards/tokens/erc-721/","ref":"Ethers.Contracts.ERC721.html","title":"Ethers.Contracts.ERC721","type":"module"},{"doc":"Default address of the contract. Returns `nil` if not specified.\n\nTo specify a default address see `Ethers.Contract`","ref":"Ethers.Contracts.ERC721.html#__default_address__/0","title":"Ethers.Contracts.ERC721.__default_address__/0","type":"function"},{"doc":"Prepares `approve(address to, uint256 tokenId)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","ref":"Ethers.Contracts.ERC721.html#approve/2","title":"Ethers.Contracts.ERC721.approve/2","type":"function"},{"doc":"- to: `:address`\n - tokenId: `{:uint, 256}`","ref":"Ethers.Contracts.ERC721.html#approve/2-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ERC721.approve/2","type":"function"},{"doc":"This function does not return any values!","ref":"Ethers.Contracts.ERC721.html#approve/2-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC721.approve/2","type":"function"},{"doc":"Prepares `balanceOf(address owner)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","ref":"Ethers.Contracts.ERC721.html#balance_of/1","title":"Ethers.Contracts.ERC721.balance_of/1","type":"function"},{"doc":"- owner: `:address`","ref":"Ethers.Contracts.ERC721.html#balance_of/1-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ERC721.balance_of/1","type":"function"},{"doc":"- `{:uint, 256}`","ref":"Ethers.Contracts.ERC721.html#balance_of/1-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC721.balance_of/1","type":"function"},{"doc":"Prepares contract constructor values for deployment.\n\nTo deploy a contracts use `Ethers.deploy/2` and pass the result of this function as\n`:encoded_constructor` option.","ref":"Ethers.Contracts.ERC721.html#constructor/0","title":"Ethers.Contracts.ERC721.constructor/0","type":"function"},{"doc":"","ref":"Ethers.Contracts.ERC721.html#constructor/0-parameters","title":"Parameters - Ethers.Contracts.ERC721.constructor/0","type":"function"},{"doc":"Prepares `getApproved(uint256 tokenId)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","ref":"Ethers.Contracts.ERC721.html#get_approved/1","title":"Ethers.Contracts.ERC721.get_approved/1","type":"function"},{"doc":"- tokenId: `{:uint, 256}`","ref":"Ethers.Contracts.ERC721.html#get_approved/1-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ERC721.get_approved/1","type":"function"},{"doc":"- `:address`","ref":"Ethers.Contracts.ERC721.html#get_approved/1-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC721.get_approved/1","type":"function"},{"doc":"Prepares `isApprovedForAll(address owner, address operator)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","ref":"Ethers.Contracts.ERC721.html#is_approved_for_all/2","title":"Ethers.Contracts.ERC721.is_approved_for_all/2","type":"function"},{"doc":"- owner: `:address`\n - operator: `:address`","ref":"Ethers.Contracts.ERC721.html#is_approved_for_all/2-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ERC721.is_approved_for_all/2","type":"function"},{"doc":"- `:bool`","ref":"Ethers.Contracts.ERC721.html#is_approved_for_all/2-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC721.is_approved_for_all/2","type":"function"},{"doc":"Prepares `name()` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","ref":"Ethers.Contracts.ERC721.html#name/0","title":"Ethers.Contracts.ERC721.name/0","type":"function"},{"doc":"- `:string`","ref":"Ethers.Contracts.ERC721.html#name/0-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC721.name/0","type":"function"},{"doc":"Prepares `ownerOf(uint256 tokenId)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","ref":"Ethers.Contracts.ERC721.html#owner_of/1","title":"Ethers.Contracts.ERC721.owner_of/1","type":"function"},{"doc":"- tokenId: `{:uint, 256}`","ref":"Ethers.Contracts.ERC721.html#owner_of/1-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ERC721.owner_of/1","type":"function"},{"doc":"- `:address`","ref":"Ethers.Contracts.ERC721.html#owner_of/1-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC721.owner_of/1","type":"function"},{"doc":"Prepares `safeTransferFrom(address from, address to, uint256 tokenId)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","ref":"Ethers.Contracts.ERC721.html#safe_transfer_from/3","title":"Ethers.Contracts.ERC721.safe_transfer_from/3","type":"function"},{"doc":"- from: `:address`\n - to: `:address`\n - tokenId: `{:uint, 256}`","ref":"Ethers.Contracts.ERC721.html#safe_transfer_from/3-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ERC721.safe_transfer_from/3","type":"function"},{"doc":"This function does not return any values!","ref":"Ethers.Contracts.ERC721.html#safe_transfer_from/3-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC721.safe_transfer_from/3","type":"function"},{"doc":"Prepares `safeTransferFrom(address from, address to, uint256 tokenId, bytes data)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","ref":"Ethers.Contracts.ERC721.html#safe_transfer_from/4","title":"Ethers.Contracts.ERC721.safe_transfer_from/4","type":"function"},{"doc":"- from: `:address`\n - to: `:address`\n - tokenId: `{:uint, 256}`\n - data: `:bytes`","ref":"Ethers.Contracts.ERC721.html#safe_transfer_from/4-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ERC721.safe_transfer_from/4","type":"function"},{"doc":"This function does not return any values!","ref":"Ethers.Contracts.ERC721.html#safe_transfer_from/4-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC721.safe_transfer_from/4","type":"function"},{"doc":"Prepares `setApprovalForAll(address operator, bool approved)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","ref":"Ethers.Contracts.ERC721.html#set_approval_for_all/2","title":"Ethers.Contracts.ERC721.set_approval_for_all/2","type":"function"},{"doc":"- operator: `:address`\n - approved: `:bool`","ref":"Ethers.Contracts.ERC721.html#set_approval_for_all/2-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ERC721.set_approval_for_all/2","type":"function"},{"doc":"This function does not return any values!","ref":"Ethers.Contracts.ERC721.html#set_approval_for_all/2-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC721.set_approval_for_all/2","type":"function"},{"doc":"Prepares `supportsInterface(bytes4 interfaceId)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","ref":"Ethers.Contracts.ERC721.html#supports_interface/1","title":"Ethers.Contracts.ERC721.supports_interface/1","type":"function"},{"doc":"- interfaceId: `{:bytes, 4}`","ref":"Ethers.Contracts.ERC721.html#supports_interface/1-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ERC721.supports_interface/1","type":"function"},{"doc":"- `:bool`","ref":"Ethers.Contracts.ERC721.html#supports_interface/1-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC721.supports_interface/1","type":"function"},{"doc":"Prepares `symbol()` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","ref":"Ethers.Contracts.ERC721.html#symbol/0","title":"Ethers.Contracts.ERC721.symbol/0","type":"function"},{"doc":"- `:string`","ref":"Ethers.Contracts.ERC721.html#symbol/0-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC721.symbol/0","type":"function"},{"doc":"Prepares `tokenURI(uint256 tokenId)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","ref":"Ethers.Contracts.ERC721.html#token_uri/1","title":"Ethers.Contracts.ERC721.token_uri/1","type":"function"},{"doc":"- tokenId: `{:uint, 256}`","ref":"Ethers.Contracts.ERC721.html#token_uri/1-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ERC721.token_uri/1","type":"function"},{"doc":"- `:string`","ref":"Ethers.Contracts.ERC721.html#token_uri/1-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC721.token_uri/1","type":"function"},{"doc":"Prepares `transferFrom(address from, address to, uint256 tokenId)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","ref":"Ethers.Contracts.ERC721.html#transfer_from/3","title":"Ethers.Contracts.ERC721.transfer_from/3","type":"function"},{"doc":"- from: `:address`\n - to: `:address`\n - tokenId: `{:uint, 256}`","ref":"Ethers.Contracts.ERC721.html#transfer_from/3-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ERC721.transfer_from/3","type":"function"},{"doc":"This function does not return any values!","ref":"Ethers.Contracts.ERC721.html#transfer_from/3-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC721.transfer_from/3","type":"function"},{"doc":"ERC777 token interface\n\nMore info: https://ethereum.org/en/developers/docs/standards/tokens/erc-777/","ref":"Ethers.Contracts.ERC777.html","title":"Ethers.Contracts.ERC777","type":"module"},{"doc":"Default address of the contract. Returns `nil` if not specified.\n\nTo specify a default address see `Ethers.Contract`","ref":"Ethers.Contracts.ERC777.html#__default_address__/0","title":"Ethers.Contracts.ERC777.__default_address__/0","type":"function"},{"doc":"Prepares `allowance(address holder, address spender)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","ref":"Ethers.Contracts.ERC777.html#allowance/2","title":"Ethers.Contracts.ERC777.allowance/2","type":"function"},{"doc":"- holder: `:address`\n - spender: `:address`","ref":"Ethers.Contracts.ERC777.html#allowance/2-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ERC777.allowance/2","type":"function"},{"doc":"- `{:uint, 256}`","ref":"Ethers.Contracts.ERC777.html#allowance/2-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC777.allowance/2","type":"function"},{"doc":"Prepares `approve(address spender, uint256 value)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","ref":"Ethers.Contracts.ERC777.html#approve/2","title":"Ethers.Contracts.ERC777.approve/2","type":"function"},{"doc":"- spender: `:address`\n - value: `{:uint, 256}`","ref":"Ethers.Contracts.ERC777.html#approve/2-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ERC777.approve/2","type":"function"},{"doc":"- `:bool`","ref":"Ethers.Contracts.ERC777.html#approve/2-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC777.approve/2","type":"function"},{"doc":"Prepares `authorizeOperator(address operator)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","ref":"Ethers.Contracts.ERC777.html#authorize_operator/1","title":"Ethers.Contracts.ERC777.authorize_operator/1","type":"function"},{"doc":"- operator: `:address`","ref":"Ethers.Contracts.ERC777.html#authorize_operator/1-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ERC777.authorize_operator/1","type":"function"},{"doc":"This function does not return any values!","ref":"Ethers.Contracts.ERC777.html#authorize_operator/1-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC777.authorize_operator/1","type":"function"},{"doc":"Prepares `balanceOf(address tokenHolder)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","ref":"Ethers.Contracts.ERC777.html#balance_of/1","title":"Ethers.Contracts.ERC777.balance_of/1","type":"function"},{"doc":"- tokenHolder: `:address`","ref":"Ethers.Contracts.ERC777.html#balance_of/1-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ERC777.balance_of/1","type":"function"},{"doc":"- `{:uint, 256}`","ref":"Ethers.Contracts.ERC777.html#balance_of/1-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC777.balance_of/1","type":"function"},{"doc":"Prepares `burn(uint256 amount, bytes data)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","ref":"Ethers.Contracts.ERC777.html#burn/2","title":"Ethers.Contracts.ERC777.burn/2","type":"function"},{"doc":"- amount: `{:uint, 256}`\n - data: `:bytes`","ref":"Ethers.Contracts.ERC777.html#burn/2-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ERC777.burn/2","type":"function"},{"doc":"This function does not return any values!","ref":"Ethers.Contracts.ERC777.html#burn/2-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC777.burn/2","type":"function"},{"doc":"Prepares contract constructor values for deployment.\n\nTo deploy a contracts use `Ethers.deploy/2` and pass the result of this function as\n`:encoded_constructor` option.","ref":"Ethers.Contracts.ERC777.html#constructor/3","title":"Ethers.Contracts.ERC777.constructor/3","type":"function"},{"doc":"- name_: `:string`\n - symbol_: `:string`\n - defaultOperators_: `{:array, :address}`","ref":"Ethers.Contracts.ERC777.html#constructor/3-parameters","title":"Parameters - Ethers.Contracts.ERC777.constructor/3","type":"function"},{"doc":"Prepares `decimals()` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `pure`","ref":"Ethers.Contracts.ERC777.html#decimals/0","title":"Ethers.Contracts.ERC777.decimals/0","type":"function"},{"doc":"- `{:uint, 8}`","ref":"Ethers.Contracts.ERC777.html#decimals/0-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC777.decimals/0","type":"function"},{"doc":"Prepares `defaultOperators()` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","ref":"Ethers.Contracts.ERC777.html#default_operators/0","title":"Ethers.Contracts.ERC777.default_operators/0","type":"function"},{"doc":"- `{:array, :address}`","ref":"Ethers.Contracts.ERC777.html#default_operators/0-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC777.default_operators/0","type":"function"},{"doc":"Prepares `granularity()` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","ref":"Ethers.Contracts.ERC777.html#granularity/0","title":"Ethers.Contracts.ERC777.granularity/0","type":"function"},{"doc":"- `{:uint, 256}`","ref":"Ethers.Contracts.ERC777.html#granularity/0-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC777.granularity/0","type":"function"},{"doc":"Prepares `isOperatorFor(address operator, address tokenHolder)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","ref":"Ethers.Contracts.ERC777.html#is_operator_for/2","title":"Ethers.Contracts.ERC777.is_operator_for/2","type":"function"},{"doc":"- operator: `:address`\n - tokenHolder: `:address`","ref":"Ethers.Contracts.ERC777.html#is_operator_for/2-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ERC777.is_operator_for/2","type":"function"},{"doc":"- `:bool`","ref":"Ethers.Contracts.ERC777.html#is_operator_for/2-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC777.is_operator_for/2","type":"function"},{"doc":"Prepares `name()` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","ref":"Ethers.Contracts.ERC777.html#name/0","title":"Ethers.Contracts.ERC777.name/0","type":"function"},{"doc":"- `:string`","ref":"Ethers.Contracts.ERC777.html#name/0-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC777.name/0","type":"function"},{"doc":"Prepares `operatorBurn(address account, uint256 amount, bytes data, bytes operatorData)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","ref":"Ethers.Contracts.ERC777.html#operator_burn/4","title":"Ethers.Contracts.ERC777.operator_burn/4","type":"function"},{"doc":"- account: `:address`\n - amount: `{:uint, 256}`\n - data: `:bytes`\n - operatorData: `:bytes`","ref":"Ethers.Contracts.ERC777.html#operator_burn/4-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ERC777.operator_burn/4","type":"function"},{"doc":"This function does not return any values!","ref":"Ethers.Contracts.ERC777.html#operator_burn/4-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC777.operator_burn/4","type":"function"},{"doc":"Prepares `operatorSend(address sender, address recipient, uint256 amount, bytes data, bytes operatorData)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","ref":"Ethers.Contracts.ERC777.html#operator_send/5","title":"Ethers.Contracts.ERC777.operator_send/5","type":"function"},{"doc":"- sender: `:address`\n - recipient: `:address`\n - amount: `{:uint, 256}`\n - data: `:bytes`\n - operatorData: `:bytes`","ref":"Ethers.Contracts.ERC777.html#operator_send/5-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ERC777.operator_send/5","type":"function"},{"doc":"This function does not return any values!","ref":"Ethers.Contracts.ERC777.html#operator_send/5-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC777.operator_send/5","type":"function"},{"doc":"Prepares `revokeOperator(address operator)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","ref":"Ethers.Contracts.ERC777.html#revoke_operator/1","title":"Ethers.Contracts.ERC777.revoke_operator/1","type":"function"},{"doc":"- operator: `:address`","ref":"Ethers.Contracts.ERC777.html#revoke_operator/1-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ERC777.revoke_operator/1","type":"function"},{"doc":"This function does not return any values!","ref":"Ethers.Contracts.ERC777.html#revoke_operator/1-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC777.revoke_operator/1","type":"function"},{"doc":"Prepares `send(address recipient, uint256 amount, bytes data)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","ref":"Ethers.Contracts.ERC777.html#send/3","title":"Ethers.Contracts.ERC777.send/3","type":"function"},{"doc":"- recipient: `:address`\n - amount: `{:uint, 256}`\n - data: `:bytes`","ref":"Ethers.Contracts.ERC777.html#send/3-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ERC777.send/3","type":"function"},{"doc":"This function does not return any values!","ref":"Ethers.Contracts.ERC777.html#send/3-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC777.send/3","type":"function"},{"doc":"Prepares `symbol()` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","ref":"Ethers.Contracts.ERC777.html#symbol/0","title":"Ethers.Contracts.ERC777.symbol/0","type":"function"},{"doc":"- `:string`","ref":"Ethers.Contracts.ERC777.html#symbol/0-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC777.symbol/0","type":"function"},{"doc":"Prepares `totalSupply()` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","ref":"Ethers.Contracts.ERC777.html#total_supply/0","title":"Ethers.Contracts.ERC777.total_supply/0","type":"function"},{"doc":"- `{:uint, 256}`","ref":"Ethers.Contracts.ERC777.html#total_supply/0-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC777.total_supply/0","type":"function"},{"doc":"Prepares `transfer(address recipient, uint256 amount)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","ref":"Ethers.Contracts.ERC777.html#transfer/2","title":"Ethers.Contracts.ERC777.transfer/2","type":"function"},{"doc":"- recipient: `:address`\n - amount: `{:uint, 256}`","ref":"Ethers.Contracts.ERC777.html#transfer/2-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ERC777.transfer/2","type":"function"},{"doc":"- `:bool`","ref":"Ethers.Contracts.ERC777.html#transfer/2-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC777.transfer/2","type":"function"},{"doc":"Prepares `transferFrom(address holder, address recipient, uint256 amount)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","ref":"Ethers.Contracts.ERC777.html#transfer_from/3","title":"Ethers.Contracts.ERC777.transfer_from/3","type":"function"},{"doc":"- holder: `:address`\n - recipient: `:address`\n - amount: `{:uint, 256}`","ref":"Ethers.Contracts.ERC777.html#transfer_from/3-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.ERC777.transfer_from/3","type":"function"},{"doc":"- `:bool`","ref":"Ethers.Contracts.ERC777.html#transfer_from/3-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC777.transfer_from/3","type":"function"},{"doc":"Multicall3 token interface\n\nMore info: https://www.multicall3.com","ref":"Ethers.Contracts.Multicall3.html","title":"Ethers.Contracts.Multicall3","type":"module"},{"doc":"Default address of the contract. Returns `nil` if not specified.\n\nTo specify a default address see `Ethers.Contract`","ref":"Ethers.Contracts.Multicall3.html#__default_address__/0","title":"Ethers.Contracts.Multicall3.__default_address__/0","type":"function"},{"doc":"Prepares `aggregate3((address,bool,bytes)[] calls)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send/2`).\nIt also supports receiving ether from the transaction origin.\n\n\nState mutability: `payable`","ref":"Ethers.Contracts.Multicall3.html#aggregate3/1","title":"Ethers.Contracts.Multicall3.aggregate3/1","type":"function"},{"doc":"- calls: `{:array, {:tuple, [:address, :bool, :bytes]}}`","ref":"Ethers.Contracts.Multicall3.html#aggregate3/1-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.Multicall3.aggregate3/1","type":"function"},{"doc":"- returnData: `{:array, {:tuple, [:bool, :bytes]}}`","ref":"Ethers.Contracts.Multicall3.html#aggregate3/1-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.Multicall3.aggregate3/1","type":"function"},{"doc":"Prepares `aggregate3Value((address,bool,uint256,bytes)[] calls)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send/2`).\nIt also supports receiving ether from the transaction origin.\n\n\nState mutability: `payable`","ref":"Ethers.Contracts.Multicall3.html#aggregate3_value/1","title":"Ethers.Contracts.Multicall3.aggregate3_value/1","type":"function"},{"doc":"- calls: `{:array, {:tuple, [:address, :bool, {:uint, 256}, :bytes]}}`","ref":"Ethers.Contracts.Multicall3.html#aggregate3_value/1-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.Multicall3.aggregate3_value/1","type":"function"},{"doc":"- returnData: `{:array, {:tuple, [:bool, :bytes]}}`","ref":"Ethers.Contracts.Multicall3.html#aggregate3_value/1-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.Multicall3.aggregate3_value/1","type":"function"},{"doc":"Prepares `aggregate((address,bytes)[] calls)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send/2`).\nIt also supports receiving ether from the transaction origin.\n\n\nState mutability: `payable`","ref":"Ethers.Contracts.Multicall3.html#aggregate/1","title":"Ethers.Contracts.Multicall3.aggregate/1","type":"function"},{"doc":"- calls: `{:array, {:tuple, [:address, :bytes]}}`","ref":"Ethers.Contracts.Multicall3.html#aggregate/1-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.Multicall3.aggregate/1","type":"function"},{"doc":"- blockNumber: `{:uint, 256}`\n - returnData: `{:array, :bytes}`","ref":"Ethers.Contracts.Multicall3.html#aggregate/1-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.Multicall3.aggregate/1","type":"function"},{"doc":"Prepares `blockAndAggregate((address,bytes)[] calls)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send/2`).\nIt also supports receiving ether from the transaction origin.\n\n\nState mutability: `payable`","ref":"Ethers.Contracts.Multicall3.html#block_and_aggregate/1","title":"Ethers.Contracts.Multicall3.block_and_aggregate/1","type":"function"},{"doc":"- calls: `{:array, {:tuple, [:address, :bytes]}}`","ref":"Ethers.Contracts.Multicall3.html#block_and_aggregate/1-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.Multicall3.block_and_aggregate/1","type":"function"},{"doc":"- blockNumber: `{:uint, 256}`\n - blockHash: `{:bytes, 32}`\n - returnData: `{:array, {:tuple, [:bool, :bytes]}}`","ref":"Ethers.Contracts.Multicall3.html#block_and_aggregate/1-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.Multicall3.block_and_aggregate/1","type":"function"},{"doc":"Prepares contract constructor values for deployment.\n\nTo deploy a contracts use `Ethers.deploy/2` and pass the result of this function as\n`:encoded_constructor` option.","ref":"Ethers.Contracts.Multicall3.html#constructor/0","title":"Ethers.Contracts.Multicall3.constructor/0","type":"function"},{"doc":"","ref":"Ethers.Contracts.Multicall3.html#constructor/0-parameters","title":"Parameters - Ethers.Contracts.Multicall3.constructor/0","type":"function"},{"doc":"Prepares `getBasefee()` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","ref":"Ethers.Contracts.Multicall3.html#get_basefee/0","title":"Ethers.Contracts.Multicall3.get_basefee/0","type":"function"},{"doc":"- basefee: `{:uint, 256}`","ref":"Ethers.Contracts.Multicall3.html#get_basefee/0-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.Multicall3.get_basefee/0","type":"function"},{"doc":"Prepares `getBlockHash(uint256 blockNumber)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","ref":"Ethers.Contracts.Multicall3.html#get_block_hash/1","title":"Ethers.Contracts.Multicall3.get_block_hash/1","type":"function"},{"doc":"- blockNumber: `{:uint, 256}`","ref":"Ethers.Contracts.Multicall3.html#get_block_hash/1-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.Multicall3.get_block_hash/1","type":"function"},{"doc":"- blockHash: `{:bytes, 32}`","ref":"Ethers.Contracts.Multicall3.html#get_block_hash/1-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.Multicall3.get_block_hash/1","type":"function"},{"doc":"Prepares `getBlockNumber()` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","ref":"Ethers.Contracts.Multicall3.html#get_block_number/0","title":"Ethers.Contracts.Multicall3.get_block_number/0","type":"function"},{"doc":"- blockNumber: `{:uint, 256}`","ref":"Ethers.Contracts.Multicall3.html#get_block_number/0-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.Multicall3.get_block_number/0","type":"function"},{"doc":"Prepares `getChainId()` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","ref":"Ethers.Contracts.Multicall3.html#get_chain_id/0","title":"Ethers.Contracts.Multicall3.get_chain_id/0","type":"function"},{"doc":"- chainid: `{:uint, 256}`","ref":"Ethers.Contracts.Multicall3.html#get_chain_id/0-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.Multicall3.get_chain_id/0","type":"function"},{"doc":"Prepares `getCurrentBlockCoinbase()` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","ref":"Ethers.Contracts.Multicall3.html#get_current_block_coinbase/0","title":"Ethers.Contracts.Multicall3.get_current_block_coinbase/0","type":"function"},{"doc":"- coinbase: `:address`","ref":"Ethers.Contracts.Multicall3.html#get_current_block_coinbase/0-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.Multicall3.get_current_block_coinbase/0","type":"function"},{"doc":"Prepares `getCurrentBlockDifficulty()` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","ref":"Ethers.Contracts.Multicall3.html#get_current_block_difficulty/0","title":"Ethers.Contracts.Multicall3.get_current_block_difficulty/0","type":"function"},{"doc":"- difficulty: `{:uint, 256}`","ref":"Ethers.Contracts.Multicall3.html#get_current_block_difficulty/0-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.Multicall3.get_current_block_difficulty/0","type":"function"},{"doc":"Prepares `getCurrentBlockGasLimit()` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","ref":"Ethers.Contracts.Multicall3.html#get_current_block_gas_limit/0","title":"Ethers.Contracts.Multicall3.get_current_block_gas_limit/0","type":"function"},{"doc":"- gaslimit: `{:uint, 256}`","ref":"Ethers.Contracts.Multicall3.html#get_current_block_gas_limit/0-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.Multicall3.get_current_block_gas_limit/0","type":"function"},{"doc":"Prepares `getCurrentBlockTimestamp()` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","ref":"Ethers.Contracts.Multicall3.html#get_current_block_timestamp/0","title":"Ethers.Contracts.Multicall3.get_current_block_timestamp/0","type":"function"},{"doc":"- timestamp: `{:uint, 256}`","ref":"Ethers.Contracts.Multicall3.html#get_current_block_timestamp/0-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.Multicall3.get_current_block_timestamp/0","type":"function"},{"doc":"Prepares `getEthBalance(address addr)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","ref":"Ethers.Contracts.Multicall3.html#get_eth_balance/1","title":"Ethers.Contracts.Multicall3.get_eth_balance/1","type":"function"},{"doc":"- addr: `:address`","ref":"Ethers.Contracts.Multicall3.html#get_eth_balance/1-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.Multicall3.get_eth_balance/1","type":"function"},{"doc":"- balance: `{:uint, 256}`","ref":"Ethers.Contracts.Multicall3.html#get_eth_balance/1-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.Multicall3.get_eth_balance/1","type":"function"},{"doc":"Prepares `getLastBlockHash()` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","ref":"Ethers.Contracts.Multicall3.html#get_last_block_hash/0","title":"Ethers.Contracts.Multicall3.get_last_block_hash/0","type":"function"},{"doc":"- blockHash: `{:bytes, 32}`","ref":"Ethers.Contracts.Multicall3.html#get_last_block_hash/0-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.Multicall3.get_last_block_hash/0","type":"function"},{"doc":"Prepares `tryAggregate(bool requireSuccess, (address,bytes)[] calls)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send/2`).\nIt also supports receiving ether from the transaction origin.\n\n\nState mutability: `payable`","ref":"Ethers.Contracts.Multicall3.html#try_aggregate/2","title":"Ethers.Contracts.Multicall3.try_aggregate/2","type":"function"},{"doc":"- requireSuccess: `:bool`\n - calls: `{:array, {:tuple, [:address, :bytes]}}`","ref":"Ethers.Contracts.Multicall3.html#try_aggregate/2-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.Multicall3.try_aggregate/2","type":"function"},{"doc":"- returnData: `{:array, {:tuple, [:bool, :bytes]}}`","ref":"Ethers.Contracts.Multicall3.html#try_aggregate/2-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.Multicall3.try_aggregate/2","type":"function"},{"doc":"Prepares `tryBlockAndAggregate(bool requireSuccess, (address,bytes)[] calls)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send/2`).\nIt also supports receiving ether from the transaction origin.\n\n\nState mutability: `payable`","ref":"Ethers.Contracts.Multicall3.html#try_block_and_aggregate/2","title":"Ethers.Contracts.Multicall3.try_block_and_aggregate/2","type":"function"},{"doc":"- requireSuccess: `:bool`\n - calls: `{:array, {:tuple, [:address, :bytes]}}`","ref":"Ethers.Contracts.Multicall3.html#try_block_and_aggregate/2-function-parameter-types","title":"Function Parameter Types - Ethers.Contracts.Multicall3.try_block_and_aggregate/2","type":"function"},{"doc":"- blockNumber: `{:uint, 256}`\n - blockHash: `{:bytes, 32}`\n - returnData: `{:array, {:tuple, [:bool, :bytes]}}`","ref":"Ethers.Contracts.Multicall3.html#try_block_and_aggregate/2-return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.Multicall3.try_block_and_aggregate/2","type":"function"},{"doc":"Events for `Ethers.Contracts.ENS`","ref":"Ethers.Contracts.ENS.EventFilters.html","title":"Ethers.Contracts.ENS.EventFilters","type":"module"},{"doc":"Create event filter for `ApprovalForAll(address owner, address operator, bool approved)`\n\nFor each indexed parameter you can either pass in the value you want to\nfilter or `nil` if you don't want to filter.","ref":"Ethers.Contracts.ENS.EventFilters.html#approval_for_all/2","title":"Ethers.Contracts.ENS.EventFilters.approval_for_all/2","type":"function"},{"doc":"- owner: `:address`\n - operator: `:address`","ref":"Ethers.Contracts.ENS.EventFilters.html#approval_for_all/2-parameter-types-event-indexed-topics","title":"Parameter Types (Event indexed topics) - Ethers.Contracts.ENS.EventFilters.approval_for_all/2","type":"function"},{"doc":"These are non-indexed topics (often referred to as data) of the event log.\n\n - approved: `:bool`","ref":"Ethers.Contracts.ENS.EventFilters.html#approval_for_all/2-event-data-types-when-called-with-ethers-get_logs-2","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Ethers.Contracts.ENS.EventFilters.approval_for_all/2","type":"function"},{"doc":"Create event filter for `NewOwner(bytes32 node, bytes32 label, address owner)`\n\nFor each indexed parameter you can either pass in the value you want to\nfilter or `nil` if you don't want to filter.","ref":"Ethers.Contracts.ENS.EventFilters.html#new_owner/2","title":"Ethers.Contracts.ENS.EventFilters.new_owner/2","type":"function"},{"doc":"- node: `{:bytes, 32}`\n - label: `{:bytes, 32}`","ref":"Ethers.Contracts.ENS.EventFilters.html#new_owner/2-parameter-types-event-indexed-topics","title":"Parameter Types (Event indexed topics) - Ethers.Contracts.ENS.EventFilters.new_owner/2","type":"function"},{"doc":"These are non-indexed topics (often referred to as data) of the event log.\n\n - owner: `:address`","ref":"Ethers.Contracts.ENS.EventFilters.html#new_owner/2-event-data-types-when-called-with-ethers-get_logs-2","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Ethers.Contracts.ENS.EventFilters.new_owner/2","type":"function"},{"doc":"Create event filter for `NewResolver(bytes32 node, address resolver)`\n\nFor each indexed parameter you can either pass in the value you want to\nfilter or `nil` if you don't want to filter.","ref":"Ethers.Contracts.ENS.EventFilters.html#new_resolver/1","title":"Ethers.Contracts.ENS.EventFilters.new_resolver/1","type":"function"},{"doc":"- node: `{:bytes, 32}`","ref":"Ethers.Contracts.ENS.EventFilters.html#new_resolver/1-parameter-types-event-indexed-topics","title":"Parameter Types (Event indexed topics) - Ethers.Contracts.ENS.EventFilters.new_resolver/1","type":"function"},{"doc":"These are non-indexed topics (often referred to as data) of the event log.\n\n - resolver: `:address`","ref":"Ethers.Contracts.ENS.EventFilters.html#new_resolver/1-event-data-types-when-called-with-ethers-get_logs-2","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Ethers.Contracts.ENS.EventFilters.new_resolver/1","type":"function"},{"doc":"Create event filter for `NewTTL(bytes32 node, uint64 ttl)`\n\nFor each indexed parameter you can either pass in the value you want to\nfilter or `nil` if you don't want to filter.","ref":"Ethers.Contracts.ENS.EventFilters.html#new_ttl/1","title":"Ethers.Contracts.ENS.EventFilters.new_ttl/1","type":"function"},{"doc":"- node: `{:bytes, 32}`","ref":"Ethers.Contracts.ENS.EventFilters.html#new_ttl/1-parameter-types-event-indexed-topics","title":"Parameter Types (Event indexed topics) - Ethers.Contracts.ENS.EventFilters.new_ttl/1","type":"function"},{"doc":"These are non-indexed topics (often referred to as data) of the event log.\n\n - ttl: `{:uint, 64}`","ref":"Ethers.Contracts.ENS.EventFilters.html#new_ttl/1-event-data-types-when-called-with-ethers-get_logs-2","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Ethers.Contracts.ENS.EventFilters.new_ttl/1","type":"function"},{"doc":"Create event filter for `Transfer(bytes32 node, address owner)`\n\nFor each indexed parameter you can either pass in the value you want to\nfilter or `nil` if you don't want to filter.","ref":"Ethers.Contracts.ENS.EventFilters.html#transfer/1","title":"Ethers.Contracts.ENS.EventFilters.transfer/1","type":"function"},{"doc":"- node: `{:bytes, 32}`","ref":"Ethers.Contracts.ENS.EventFilters.html#transfer/1-parameter-types-event-indexed-topics","title":"Parameter Types (Event indexed topics) - Ethers.Contracts.ENS.EventFilters.transfer/1","type":"function"},{"doc":"These are non-indexed topics (often referred to as data) of the event log.\n\n - owner: `:address`","ref":"Ethers.Contracts.ENS.EventFilters.html#transfer/1-event-data-types-when-called-with-ethers-get_logs-2","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Ethers.Contracts.ENS.EventFilters.transfer/1","type":"function"},{"doc":"Events for `Ethers.Contracts.ENS.Resolver`","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html","title":"Ethers.Contracts.ENS.Resolver.EventFilters","type":"module"},{"doc":"Create event filter for `ABIChanged(bytes32 node, uint256 contentType)`\n\nFor each indexed parameter you can either pass in the value you want to\nfilter or `nil` if you don't want to filter.","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#abi_changed/2","title":"Ethers.Contracts.ENS.Resolver.EventFilters.abi_changed/2","type":"function"},{"doc":"- node: `{:bytes, 32}`\n - contentType: `{:uint, 256}`","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#abi_changed/2-parameter-types-event-indexed-topics","title":"Parameter Types (Event indexed topics) - Ethers.Contracts.ENS.Resolver.EventFilters.abi_changed/2","type":"function"},{"doc":"These are non-indexed topics (often referred to as data) of the event log.\n\nThis event does not contain any values!","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#abi_changed/2-event-data-types-when-called-with-ethers-get_logs-2","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Ethers.Contracts.ENS.Resolver.EventFilters.abi_changed/2","type":"function"},{"doc":"Create event filter for `AddrChanged(bytes32 node, address a)`\n\nFor each indexed parameter you can either pass in the value you want to\nfilter or `nil` if you don't want to filter.","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#addr_changed/1","title":"Ethers.Contracts.ENS.Resolver.EventFilters.addr_changed/1","type":"function"},{"doc":"- node: `{:bytes, 32}`","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#addr_changed/1-parameter-types-event-indexed-topics","title":"Parameter Types (Event indexed topics) - Ethers.Contracts.ENS.Resolver.EventFilters.addr_changed/1","type":"function"},{"doc":"These are non-indexed topics (often referred to as data) of the event log.\n\n - a: `:address`","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#addr_changed/1-event-data-types-when-called-with-ethers-get_logs-2","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Ethers.Contracts.ENS.Resolver.EventFilters.addr_changed/1","type":"function"},{"doc":"Create event filter for `AddressChanged(bytes32 node, uint256 coinType, bytes newAddress)`\n\nFor each indexed parameter you can either pass in the value you want to\nfilter or `nil` if you don't want to filter.","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#address_changed/1","title":"Ethers.Contracts.ENS.Resolver.EventFilters.address_changed/1","type":"function"},{"doc":"- node: `{:bytes, 32}`","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#address_changed/1-parameter-types-event-indexed-topics","title":"Parameter Types (Event indexed topics) - Ethers.Contracts.ENS.Resolver.EventFilters.address_changed/1","type":"function"},{"doc":"These are non-indexed topics (often referred to as data) of the event log.\n\n - coinType: `{:uint, 256}`\n - newAddress: `:bytes`","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#address_changed/1-event-data-types-when-called-with-ethers-get_logs-2","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Ethers.Contracts.ENS.Resolver.EventFilters.address_changed/1","type":"function"},{"doc":"Create event filter for `AuthorisationChanged(bytes32 node, address owner, address target, bool isAuthorised)`\n\nFor each indexed parameter you can either pass in the value you want to\nfilter or `nil` if you don't want to filter.","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#authorisation_changed/3","title":"Ethers.Contracts.ENS.Resolver.EventFilters.authorisation_changed/3","type":"function"},{"doc":"- node: `{:bytes, 32}`\n - owner: `:address`\n - target: `:address`","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#authorisation_changed/3-parameter-types-event-indexed-topics","title":"Parameter Types (Event indexed topics) - Ethers.Contracts.ENS.Resolver.EventFilters.authorisation_changed/3","type":"function"},{"doc":"These are non-indexed topics (often referred to as data) of the event log.\n\n - isAuthorised: `:bool`","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#authorisation_changed/3-event-data-types-when-called-with-ethers-get_logs-2","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Ethers.Contracts.ENS.Resolver.EventFilters.authorisation_changed/3","type":"function"},{"doc":"Create event filter for `ContenthashChanged(bytes32 node, bytes hash)`\n\nFor each indexed parameter you can either pass in the value you want to\nfilter or `nil` if you don't want to filter.","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#contenthash_changed/1","title":"Ethers.Contracts.ENS.Resolver.EventFilters.contenthash_changed/1","type":"function"},{"doc":"- node: `{:bytes, 32}`","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#contenthash_changed/1-parameter-types-event-indexed-topics","title":"Parameter Types (Event indexed topics) - Ethers.Contracts.ENS.Resolver.EventFilters.contenthash_changed/1","type":"function"},{"doc":"These are non-indexed topics (often referred to as data) of the event log.\n\n - hash: `:bytes`","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#contenthash_changed/1-event-data-types-when-called-with-ethers-get_logs-2","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Ethers.Contracts.ENS.Resolver.EventFilters.contenthash_changed/1","type":"function"},{"doc":"Create event filter for `DNSRecordChanged(bytes32 node, bytes name, uint16 resource, bytes record)`\n\nFor each indexed parameter you can either pass in the value you want to\nfilter or `nil` if you don't want to filter.","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#dns_record_changed/1","title":"Ethers.Contracts.ENS.Resolver.EventFilters.dns_record_changed/1","type":"function"},{"doc":"- node: `{:bytes, 32}`","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#dns_record_changed/1-parameter-types-event-indexed-topics","title":"Parameter Types (Event indexed topics) - Ethers.Contracts.ENS.Resolver.EventFilters.dns_record_changed/1","type":"function"},{"doc":"These are non-indexed topics (often referred to as data) of the event log.\n\n - name: `:bytes`\n - resource: `{:uint, 16}`\n - record: `:bytes`","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#dns_record_changed/1-event-data-types-when-called-with-ethers-get_logs-2","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Ethers.Contracts.ENS.Resolver.EventFilters.dns_record_changed/1","type":"function"},{"doc":"Create event filter for `DNSRecordDeleted(bytes32 node, bytes name, uint16 resource)`\n\nFor each indexed parameter you can either pass in the value you want to\nfilter or `nil` if you don't want to filter.","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#dns_record_deleted/1","title":"Ethers.Contracts.ENS.Resolver.EventFilters.dns_record_deleted/1","type":"function"},{"doc":"- node: `{:bytes, 32}`","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#dns_record_deleted/1-parameter-types-event-indexed-topics","title":"Parameter Types (Event indexed topics) - Ethers.Contracts.ENS.Resolver.EventFilters.dns_record_deleted/1","type":"function"},{"doc":"These are non-indexed topics (often referred to as data) of the event log.\n\n - name: `:bytes`\n - resource: `{:uint, 16}`","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#dns_record_deleted/1-event-data-types-when-called-with-ethers-get_logs-2","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Ethers.Contracts.ENS.Resolver.EventFilters.dns_record_deleted/1","type":"function"},{"doc":"Create event filter for `DNSZoneCleared(bytes32 node)`\n\nFor each indexed parameter you can either pass in the value you want to\nfilter or `nil` if you don't want to filter.","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#dns_zone_cleared/1","title":"Ethers.Contracts.ENS.Resolver.EventFilters.dns_zone_cleared/1","type":"function"},{"doc":"- node: `{:bytes, 32}`","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#dns_zone_cleared/1-parameter-types-event-indexed-topics","title":"Parameter Types (Event indexed topics) - Ethers.Contracts.ENS.Resolver.EventFilters.dns_zone_cleared/1","type":"function"},{"doc":"These are non-indexed topics (often referred to as data) of the event log.\n\nThis event does not contain any values!","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#dns_zone_cleared/1-event-data-types-when-called-with-ethers-get_logs-2","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Ethers.Contracts.ENS.Resolver.EventFilters.dns_zone_cleared/1","type":"function"},{"doc":"Create event filter for `InterfaceChanged(bytes32 node, bytes4 interfaceID, address implementer)`\n\nFor each indexed parameter you can either pass in the value you want to\nfilter or `nil` if you don't want to filter.","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#interface_changed/2","title":"Ethers.Contracts.ENS.Resolver.EventFilters.interface_changed/2","type":"function"},{"doc":"- node: `{:bytes, 32}`\n - interfaceID: `{:bytes, 4}`","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#interface_changed/2-parameter-types-event-indexed-topics","title":"Parameter Types (Event indexed topics) - Ethers.Contracts.ENS.Resolver.EventFilters.interface_changed/2","type":"function"},{"doc":"These are non-indexed topics (often referred to as data) of the event log.\n\n - implementer: `:address`","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#interface_changed/2-event-data-types-when-called-with-ethers-get_logs-2","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Ethers.Contracts.ENS.Resolver.EventFilters.interface_changed/2","type":"function"},{"doc":"Create event filter for `NameChanged(bytes32 node, string name)`\n\nFor each indexed parameter you can either pass in the value you want to\nfilter or `nil` if you don't want to filter.","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#name_changed/1","title":"Ethers.Contracts.ENS.Resolver.EventFilters.name_changed/1","type":"function"},{"doc":"- node: `{:bytes, 32}`","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#name_changed/1-parameter-types-event-indexed-topics","title":"Parameter Types (Event indexed topics) - Ethers.Contracts.ENS.Resolver.EventFilters.name_changed/1","type":"function"},{"doc":"These are non-indexed topics (often referred to as data) of the event log.\n\n - name: `:string`","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#name_changed/1-event-data-types-when-called-with-ethers-get_logs-2","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Ethers.Contracts.ENS.Resolver.EventFilters.name_changed/1","type":"function"},{"doc":"Create event filter for `PubkeyChanged(bytes32 node, bytes32 x, bytes32 y)`\n\nFor each indexed parameter you can either pass in the value you want to\nfilter or `nil` if you don't want to filter.","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#pubkey_changed/1","title":"Ethers.Contracts.ENS.Resolver.EventFilters.pubkey_changed/1","type":"function"},{"doc":"- node: `{:bytes, 32}`","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#pubkey_changed/1-parameter-types-event-indexed-topics","title":"Parameter Types (Event indexed topics) - Ethers.Contracts.ENS.Resolver.EventFilters.pubkey_changed/1","type":"function"},{"doc":"These are non-indexed topics (often referred to as data) of the event log.\n\n - x: `{:bytes, 32}`\n - y: `{:bytes, 32}`","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#pubkey_changed/1-event-data-types-when-called-with-ethers-get_logs-2","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Ethers.Contracts.ENS.Resolver.EventFilters.pubkey_changed/1","type":"function"},{"doc":"Create event filter for `TextChanged(bytes32 node, string indexedKey, string key)`\n\nFor each indexed parameter you can either pass in the value you want to\nfilter or `nil` if you don't want to filter.","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#text_changed/2","title":"Ethers.Contracts.ENS.Resolver.EventFilters.text_changed/2","type":"function"},{"doc":"- node: `{:bytes, 32}`\n - indexedKey: `:string`","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#text_changed/2-parameter-types-event-indexed-topics","title":"Parameter Types (Event indexed topics) - Ethers.Contracts.ENS.Resolver.EventFilters.text_changed/2","type":"function"},{"doc":"These are non-indexed topics (often referred to as data) of the event log.\n\n - key: `:string`","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#text_changed/2-event-data-types-when-called-with-ethers-get_logs-2","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Ethers.Contracts.ENS.Resolver.EventFilters.text_changed/2","type":"function"},{"doc":"Events for `Ethers.Contracts.ERC1155`","ref":"Ethers.Contracts.ERC1155.EventFilters.html","title":"Ethers.Contracts.ERC1155.EventFilters","type":"module"},{"doc":"Create event filter for `ApprovalForAll(address account, address operator, bool approved)`\n\nFor each indexed parameter you can either pass in the value you want to\nfilter or `nil` if you don't want to filter.","ref":"Ethers.Contracts.ERC1155.EventFilters.html#approval_for_all/2","title":"Ethers.Contracts.ERC1155.EventFilters.approval_for_all/2","type":"function"},{"doc":"- account: `:address`\n - operator: `:address`","ref":"Ethers.Contracts.ERC1155.EventFilters.html#approval_for_all/2-parameter-types-event-indexed-topics","title":"Parameter Types (Event indexed topics) - Ethers.Contracts.ERC1155.EventFilters.approval_for_all/2","type":"function"},{"doc":"These are non-indexed topics (often referred to as data) of the event log.\n\n - approved: `:bool`","ref":"Ethers.Contracts.ERC1155.EventFilters.html#approval_for_all/2-event-data-types-when-called-with-ethers-get_logs-2","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Ethers.Contracts.ERC1155.EventFilters.approval_for_all/2","type":"function"},{"doc":"Create event filter for `TransferBatch(address operator, address from, address to, uint256[] ids, uint256[] values)`\n\nFor each indexed parameter you can either pass in the value you want to\nfilter or `nil` if you don't want to filter.","ref":"Ethers.Contracts.ERC1155.EventFilters.html#transfer_batch/3","title":"Ethers.Contracts.ERC1155.EventFilters.transfer_batch/3","type":"function"},{"doc":"- operator: `:address`\n - from: `:address`\n - to: `:address`","ref":"Ethers.Contracts.ERC1155.EventFilters.html#transfer_batch/3-parameter-types-event-indexed-topics","title":"Parameter Types (Event indexed topics) - Ethers.Contracts.ERC1155.EventFilters.transfer_batch/3","type":"function"},{"doc":"These are non-indexed topics (often referred to as data) of the event log.\n\n - ids: `{:array, {:uint, 256}}`\n - values: `{:array, {:uint, 256}}`","ref":"Ethers.Contracts.ERC1155.EventFilters.html#transfer_batch/3-event-data-types-when-called-with-ethers-get_logs-2","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Ethers.Contracts.ERC1155.EventFilters.transfer_batch/3","type":"function"},{"doc":"Create event filter for `TransferSingle(address operator, address from, address to, uint256 id, uint256 value)`\n\nFor each indexed parameter you can either pass in the value you want to\nfilter or `nil` if you don't want to filter.","ref":"Ethers.Contracts.ERC1155.EventFilters.html#transfer_single/3","title":"Ethers.Contracts.ERC1155.EventFilters.transfer_single/3","type":"function"},{"doc":"- operator: `:address`\n - from: `:address`\n - to: `:address`","ref":"Ethers.Contracts.ERC1155.EventFilters.html#transfer_single/3-parameter-types-event-indexed-topics","title":"Parameter Types (Event indexed topics) - Ethers.Contracts.ERC1155.EventFilters.transfer_single/3","type":"function"},{"doc":"These are non-indexed topics (often referred to as data) of the event log.\n\n - id: `{:uint, 256}`\n - value: `{:uint, 256}`","ref":"Ethers.Contracts.ERC1155.EventFilters.html#transfer_single/3-event-data-types-when-called-with-ethers-get_logs-2","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Ethers.Contracts.ERC1155.EventFilters.transfer_single/3","type":"function"},{"doc":"Create event filter for `URI(string value, uint256 id)`\n\nFor each indexed parameter you can either pass in the value you want to\nfilter or `nil` if you don't want to filter.","ref":"Ethers.Contracts.ERC1155.EventFilters.html#uri/1","title":"Ethers.Contracts.ERC1155.EventFilters.uri/1","type":"function"},{"doc":"- id: `{:uint, 256}`","ref":"Ethers.Contracts.ERC1155.EventFilters.html#uri/1-parameter-types-event-indexed-topics","title":"Parameter Types (Event indexed topics) - Ethers.Contracts.ERC1155.EventFilters.uri/1","type":"function"},{"doc":"These are non-indexed topics (often referred to as data) of the event log.\n\n - value: `:string`","ref":"Ethers.Contracts.ERC1155.EventFilters.html#uri/1-event-data-types-when-called-with-ethers-get_logs-2","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Ethers.Contracts.ERC1155.EventFilters.uri/1","type":"function"},{"doc":"Events for `Ethers.Contracts.ERC20`","ref":"Ethers.Contracts.ERC20.EventFilters.html","title":"Ethers.Contracts.ERC20.EventFilters","type":"module"},{"doc":"Create event filter for `Approval(address owner, address spender, uint256 value)`\n\nFor each indexed parameter you can either pass in the value you want to\nfilter or `nil` if you don't want to filter.","ref":"Ethers.Contracts.ERC20.EventFilters.html#approval/2","title":"Ethers.Contracts.ERC20.EventFilters.approval/2","type":"function"},{"doc":"- owner: `:address`\n - spender: `:address`","ref":"Ethers.Contracts.ERC20.EventFilters.html#approval/2-parameter-types-event-indexed-topics","title":"Parameter Types (Event indexed topics) - Ethers.Contracts.ERC20.EventFilters.approval/2","type":"function"},{"doc":"These are non-indexed topics (often referred to as data) of the event log.\n\n - value: `{:uint, 256}`","ref":"Ethers.Contracts.ERC20.EventFilters.html#approval/2-event-data-types-when-called-with-ethers-get_logs-2","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Ethers.Contracts.ERC20.EventFilters.approval/2","type":"function"},{"doc":"Create event filter for `Transfer(address from, address to, uint256 value)`\n\nFor each indexed parameter you can either pass in the value you want to\nfilter or `nil` if you don't want to filter.","ref":"Ethers.Contracts.ERC20.EventFilters.html#transfer/2","title":"Ethers.Contracts.ERC20.EventFilters.transfer/2","type":"function"},{"doc":"- from: `:address`\n - to: `:address`","ref":"Ethers.Contracts.ERC20.EventFilters.html#transfer/2-parameter-types-event-indexed-topics","title":"Parameter Types (Event indexed topics) - Ethers.Contracts.ERC20.EventFilters.transfer/2","type":"function"},{"doc":"These are non-indexed topics (often referred to as data) of the event log.\n\n - value: `{:uint, 256}`","ref":"Ethers.Contracts.ERC20.EventFilters.html#transfer/2-event-data-types-when-called-with-ethers-get_logs-2","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Ethers.Contracts.ERC20.EventFilters.transfer/2","type":"function"},{"doc":"Events for `Ethers.Contracts.ERC721`","ref":"Ethers.Contracts.ERC721.EventFilters.html","title":"Ethers.Contracts.ERC721.EventFilters","type":"module"},{"doc":"Create event filter for `Approval(address owner, address approved, uint256 tokenId)`\n\nFor each indexed parameter you can either pass in the value you want to\nfilter or `nil` if you don't want to filter.","ref":"Ethers.Contracts.ERC721.EventFilters.html#approval/3","title":"Ethers.Contracts.ERC721.EventFilters.approval/3","type":"function"},{"doc":"- owner: `:address`\n - approved: `:address`\n - tokenId: `{:uint, 256}`","ref":"Ethers.Contracts.ERC721.EventFilters.html#approval/3-parameter-types-event-indexed-topics","title":"Parameter Types (Event indexed topics) - Ethers.Contracts.ERC721.EventFilters.approval/3","type":"function"},{"doc":"These are non-indexed topics (often referred to as data) of the event log.\n\nThis event does not contain any values!","ref":"Ethers.Contracts.ERC721.EventFilters.html#approval/3-event-data-types-when-called-with-ethers-get_logs-2","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Ethers.Contracts.ERC721.EventFilters.approval/3","type":"function"},{"doc":"Create event filter for `ApprovalForAll(address owner, address operator, bool approved)`\n\nFor each indexed parameter you can either pass in the value you want to\nfilter or `nil` if you don't want to filter.","ref":"Ethers.Contracts.ERC721.EventFilters.html#approval_for_all/2","title":"Ethers.Contracts.ERC721.EventFilters.approval_for_all/2","type":"function"},{"doc":"- owner: `:address`\n - operator: `:address`","ref":"Ethers.Contracts.ERC721.EventFilters.html#approval_for_all/2-parameter-types-event-indexed-topics","title":"Parameter Types (Event indexed topics) - Ethers.Contracts.ERC721.EventFilters.approval_for_all/2","type":"function"},{"doc":"These are non-indexed topics (often referred to as data) of the event log.\n\n - approved: `:bool`","ref":"Ethers.Contracts.ERC721.EventFilters.html#approval_for_all/2-event-data-types-when-called-with-ethers-get_logs-2","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Ethers.Contracts.ERC721.EventFilters.approval_for_all/2","type":"function"},{"doc":"Create event filter for `Transfer(address from, address to, uint256 tokenId)`\n\nFor each indexed parameter you can either pass in the value you want to\nfilter or `nil` if you don't want to filter.","ref":"Ethers.Contracts.ERC721.EventFilters.html#transfer/3","title":"Ethers.Contracts.ERC721.EventFilters.transfer/3","type":"function"},{"doc":"- from: `:address`\n - to: `:address`\n - tokenId: `{:uint, 256}`","ref":"Ethers.Contracts.ERC721.EventFilters.html#transfer/3-parameter-types-event-indexed-topics","title":"Parameter Types (Event indexed topics) - Ethers.Contracts.ERC721.EventFilters.transfer/3","type":"function"},{"doc":"These are non-indexed topics (often referred to as data) of the event log.\n\nThis event does not contain any values!","ref":"Ethers.Contracts.ERC721.EventFilters.html#transfer/3-event-data-types-when-called-with-ethers-get_logs-2","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Ethers.Contracts.ERC721.EventFilters.transfer/3","type":"function"},{"doc":"Events for `Ethers.Contracts.ERC777`","ref":"Ethers.Contracts.ERC777.EventFilters.html","title":"Ethers.Contracts.ERC777.EventFilters","type":"module"},{"doc":"Create event filter for `Approval(address owner, address spender, uint256 value)`\n\nFor each indexed parameter you can either pass in the value you want to\nfilter or `nil` if you don't want to filter.","ref":"Ethers.Contracts.ERC777.EventFilters.html#approval/2","title":"Ethers.Contracts.ERC777.EventFilters.approval/2","type":"function"},{"doc":"- owner: `:address`\n - spender: `:address`","ref":"Ethers.Contracts.ERC777.EventFilters.html#approval/2-parameter-types-event-indexed-topics","title":"Parameter Types (Event indexed topics) - Ethers.Contracts.ERC777.EventFilters.approval/2","type":"function"},{"doc":"These are non-indexed topics (often referred to as data) of the event log.\n\n - value: `{:uint, 256}`","ref":"Ethers.Contracts.ERC777.EventFilters.html#approval/2-event-data-types-when-called-with-ethers-get_logs-2","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Ethers.Contracts.ERC777.EventFilters.approval/2","type":"function"},{"doc":"Create event filter for `AuthorizedOperator(address operator, address tokenHolder)`\n\nFor each indexed parameter you can either pass in the value you want to\nfilter or `nil` if you don't want to filter.","ref":"Ethers.Contracts.ERC777.EventFilters.html#authorized_operator/2","title":"Ethers.Contracts.ERC777.EventFilters.authorized_operator/2","type":"function"},{"doc":"- operator: `:address`\n - tokenHolder: `:address`","ref":"Ethers.Contracts.ERC777.EventFilters.html#authorized_operator/2-parameter-types-event-indexed-topics","title":"Parameter Types (Event indexed topics) - Ethers.Contracts.ERC777.EventFilters.authorized_operator/2","type":"function"},{"doc":"These are non-indexed topics (often referred to as data) of the event log.\n\nThis event does not contain any values!","ref":"Ethers.Contracts.ERC777.EventFilters.html#authorized_operator/2-event-data-types-when-called-with-ethers-get_logs-2","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Ethers.Contracts.ERC777.EventFilters.authorized_operator/2","type":"function"},{"doc":"Create event filter for `Burned(address operator, address from, uint256 amount, bytes data, bytes operatorData)`\n\nFor each indexed parameter you can either pass in the value you want to\nfilter or `nil` if you don't want to filter.","ref":"Ethers.Contracts.ERC777.EventFilters.html#burned/2","title":"Ethers.Contracts.ERC777.EventFilters.burned/2","type":"function"},{"doc":"- operator: `:address`\n - from: `:address`","ref":"Ethers.Contracts.ERC777.EventFilters.html#burned/2-parameter-types-event-indexed-topics","title":"Parameter Types (Event indexed topics) - Ethers.Contracts.ERC777.EventFilters.burned/2","type":"function"},{"doc":"These are non-indexed topics (often referred to as data) of the event log.\n\n - amount: `{:uint, 256}`\n - data: `:bytes`\n - operatorData: `:bytes`","ref":"Ethers.Contracts.ERC777.EventFilters.html#burned/2-event-data-types-when-called-with-ethers-get_logs-2","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Ethers.Contracts.ERC777.EventFilters.burned/2","type":"function"},{"doc":"Create event filter for `Minted(address operator, address to, uint256 amount, bytes data, bytes operatorData)`\n\nFor each indexed parameter you can either pass in the value you want to\nfilter or `nil` if you don't want to filter.","ref":"Ethers.Contracts.ERC777.EventFilters.html#minted/2","title":"Ethers.Contracts.ERC777.EventFilters.minted/2","type":"function"},{"doc":"- operator: `:address`\n - to: `:address`","ref":"Ethers.Contracts.ERC777.EventFilters.html#minted/2-parameter-types-event-indexed-topics","title":"Parameter Types (Event indexed topics) - Ethers.Contracts.ERC777.EventFilters.minted/2","type":"function"},{"doc":"These are non-indexed topics (often referred to as data) of the event log.\n\n - amount: `{:uint, 256}`\n - data: `:bytes`\n - operatorData: `:bytes`","ref":"Ethers.Contracts.ERC777.EventFilters.html#minted/2-event-data-types-when-called-with-ethers-get_logs-2","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Ethers.Contracts.ERC777.EventFilters.minted/2","type":"function"},{"doc":"Create event filter for `RevokedOperator(address operator, address tokenHolder)`\n\nFor each indexed parameter you can either pass in the value you want to\nfilter or `nil` if you don't want to filter.","ref":"Ethers.Contracts.ERC777.EventFilters.html#revoked_operator/2","title":"Ethers.Contracts.ERC777.EventFilters.revoked_operator/2","type":"function"},{"doc":"- operator: `:address`\n - tokenHolder: `:address`","ref":"Ethers.Contracts.ERC777.EventFilters.html#revoked_operator/2-parameter-types-event-indexed-topics","title":"Parameter Types (Event indexed topics) - Ethers.Contracts.ERC777.EventFilters.revoked_operator/2","type":"function"},{"doc":"These are non-indexed topics (often referred to as data) of the event log.\n\nThis event does not contain any values!","ref":"Ethers.Contracts.ERC777.EventFilters.html#revoked_operator/2-event-data-types-when-called-with-ethers-get_logs-2","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Ethers.Contracts.ERC777.EventFilters.revoked_operator/2","type":"function"},{"doc":"Create event filter for `Sent(address operator, address from, address to, uint256 amount, bytes data, bytes operatorData)`\n\nFor each indexed parameter you can either pass in the value you want to\nfilter or `nil` if you don't want to filter.","ref":"Ethers.Contracts.ERC777.EventFilters.html#sent/3","title":"Ethers.Contracts.ERC777.EventFilters.sent/3","type":"function"},{"doc":"- operator: `:address`\n - from: `:address`\n - to: `:address`","ref":"Ethers.Contracts.ERC777.EventFilters.html#sent/3-parameter-types-event-indexed-topics","title":"Parameter Types (Event indexed topics) - Ethers.Contracts.ERC777.EventFilters.sent/3","type":"function"},{"doc":"These are non-indexed topics (often referred to as data) of the event log.\n\n - amount: `{:uint, 256}`\n - data: `:bytes`\n - operatorData: `:bytes`","ref":"Ethers.Contracts.ERC777.EventFilters.html#sent/3-event-data-types-when-called-with-ethers-get_logs-2","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Ethers.Contracts.ERC777.EventFilters.sent/3","type":"function"},{"doc":"Create event filter for `Transfer(address from, address to, uint256 value)`\n\nFor each indexed parameter you can either pass in the value you want to\nfilter or `nil` if you don't want to filter.","ref":"Ethers.Contracts.ERC777.EventFilters.html#transfer/2","title":"Ethers.Contracts.ERC777.EventFilters.transfer/2","type":"function"},{"doc":"- from: `:address`\n - to: `:address`","ref":"Ethers.Contracts.ERC777.EventFilters.html#transfer/2-parameter-types-event-indexed-topics","title":"Parameter Types (Event indexed topics) - Ethers.Contracts.ERC777.EventFilters.transfer/2","type":"function"},{"doc":"These are non-indexed topics (often referred to as data) of the event log.\n\n - value: `{:uint, 256}`","ref":"Ethers.Contracts.ERC777.EventFilters.html#transfer/2-event-data-types-when-called-with-ethers-get_logs-2","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Ethers.Contracts.ERC777.EventFilters.transfer/2","type":"function"},{"doc":"Events for `Ethers.Contracts.Multicall3`","ref":"Ethers.Contracts.Multicall3.EventFilters.html","title":"Ethers.Contracts.Multicall3.EventFilters","type":"module"},{"doc":"Signer behaviour.\n\nA signer module is (at least) capable of signing transactions and listing accounts in the signer.","ref":"Ethers.Signer.html","title":"Ethers.Signer","type":"behaviour"},{"doc":"Ethers ships with some default signers that you can use.\n\n- `Ethers.Signer.JsonRPC`: Can be used with most wallets, geth, web3signer or any other platform\n  which exposes a JsonRPC endpoint and implements `eth_signTransaction` and `eth_accounts`\n  functions.\n- `Ethers.Signer.Local`: This signs transactions locally but is highly discouraged to use in\n  a production environment as it does not have any security measures built in.","ref":"Ethers.Signer.html#module-builtin-signers","title":"Builtin Signers - Ethers.Signer","type":"behaviour"},{"doc":"Custom signers can also be implemented which must adhere to this behvaviour.\n\nFor signing transactions in custom signers the functions in `Ethers.Transaction` module might\nbecome handy. Check out the source code of built in signers for in depth info.","ref":"Ethers.Signer.html#module-custom-signers","title":"Custom Signers - Ethers.Signer","type":"behaviour"},{"doc":"If desired, a signer can be configured to be used for all operations in Ethers using elixir\nconfig.\n\n```elixir\nconfig :ethers,\n  default_signer: Ethers.Signer.JsonRPC,\n  default_signer_opts: [url: \"...\"]\n```","ref":"Ethers.Signer.html#module-globally-default-signer","title":"Globally Default Signer - Ethers.Signer","type":"behaviour"},{"doc":"Returns the available signer account addresses.\n\nThis method might not be supported by all signers. If a signer does not support this function\nit should return `{:error, :not_supported}`.","ref":"Ethers.Signer.html#c:accounts/1","title":"Ethers.Signer.accounts/1","type":"callback"},{"doc":"- opts: Other options passed to the signer as `signer_opts`","ref":"Ethers.Signer.html#c:accounts/1-parameters","title":"Parameters - Ethers.Signer.accounts/1","type":"callback"},{"doc":"Signs a binary and returns the signature","ref":"Ethers.Signer.html#c:sign_transaction/2","title":"Ethers.Signer.sign_transaction/2","type":"callback"},{"doc":"- tx: The transaction object. (An `Ethers.Transaction` struct)\n - opts: Other options passed to the signer as `signer_opts`.","ref":"Ethers.Signer.html#c:sign_transaction/2-parameters","title":"Parameters - Ethers.Signer.sign_transaction/2","type":"callback"},{"doc":"Signer capable of signing transactions with a JSON RPC server\ncapable of `eth_signTransaction` and `eth_accounts` RPC functions.","ref":"Ethers.Signer.JsonRPC.html","title":"Ethers.Signer.JsonRPC","type":"module"},{"doc":"- `:rpc_module`: The RPC Module to use. (Optional, Defaults to `Ethereumex.HttpClient`)\n- `:url`: The RPC URL to use. (Optional)\n\n** All other options will be passed to the RPC module `request/3` function in\nthe third argument **","ref":"Ethers.Signer.JsonRPC.html#module-signer-options","title":"Signer Options - Ethers.Signer.JsonRPC","type":"module"},{"doc":"Local signer works with a private key.\n\nIMPORTANT: Please note that using this signer is discouraged in production\nenvironment since handling private keys in those environment can be challenging\nif you don't know what you are doing.","ref":"Ethers.Signer.Local.html","title":"Ethers.Signer.Local","type":"module"},{"doc":"- `:private_key`: The private key to use for signing and calculating account address.\n   Private key can either be in binary format (32 bytes) or it's hex encoded format with or\n   without `0x` prefix.","ref":"Ethers.Signer.Local.html#module-signer-options","title":"Signer Options - Ethers.Signer.Local","type":"module"},{"doc":"Error struct for `error ERC1155InsufficientBalance`","ref":"Ethers.Contracts.ERC1155.Errors.ERC1155InsufficientBalance.html","title":"Ethers.Contracts.ERC1155.Errors.ERC1155InsufficientBalance","type":"module"},{"doc":"","ref":"Ethers.Contracts.ERC1155.Errors.ERC1155InsufficientBalance.html#t:t/0","title":"Ethers.Contracts.ERC1155.Errors.ERC1155InsufficientBalance.t/0","type":"type"},{"doc":"Error struct for `error ERC1155InvalidApprover`","ref":"Ethers.Contracts.ERC1155.Errors.ERC1155InvalidApprover.html","title":"Ethers.Contracts.ERC1155.Errors.ERC1155InvalidApprover","type":"module"},{"doc":"","ref":"Ethers.Contracts.ERC1155.Errors.ERC1155InvalidApprover.html#t:t/0","title":"Ethers.Contracts.ERC1155.Errors.ERC1155InvalidApprover.t/0","type":"type"},{"doc":"Error struct for `error ERC1155InvalidArrayLength`","ref":"Ethers.Contracts.ERC1155.Errors.ERC1155InvalidArrayLength.html","title":"Ethers.Contracts.ERC1155.Errors.ERC1155InvalidArrayLength","type":"module"},{"doc":"","ref":"Ethers.Contracts.ERC1155.Errors.ERC1155InvalidArrayLength.html#t:t/0","title":"Ethers.Contracts.ERC1155.Errors.ERC1155InvalidArrayLength.t/0","type":"type"},{"doc":"Error struct for `error ERC1155InvalidOperator`","ref":"Ethers.Contracts.ERC1155.Errors.ERC1155InvalidOperator.html","title":"Ethers.Contracts.ERC1155.Errors.ERC1155InvalidOperator","type":"module"},{"doc":"","ref":"Ethers.Contracts.ERC1155.Errors.ERC1155InvalidOperator.html#t:t/0","title":"Ethers.Contracts.ERC1155.Errors.ERC1155InvalidOperator.t/0","type":"type"},{"doc":"Error struct for `error ERC1155InvalidReceiver`","ref":"Ethers.Contracts.ERC1155.Errors.ERC1155InvalidReceiver.html","title":"Ethers.Contracts.ERC1155.Errors.ERC1155InvalidReceiver","type":"module"},{"doc":"","ref":"Ethers.Contracts.ERC1155.Errors.ERC1155InvalidReceiver.html#t:t/0","title":"Ethers.Contracts.ERC1155.Errors.ERC1155InvalidReceiver.t/0","type":"type"},{"doc":"Error struct for `error ERC1155InvalidSender`","ref":"Ethers.Contracts.ERC1155.Errors.ERC1155InvalidSender.html","title":"Ethers.Contracts.ERC1155.Errors.ERC1155InvalidSender","type":"module"},{"doc":"","ref":"Ethers.Contracts.ERC1155.Errors.ERC1155InvalidSender.html#t:t/0","title":"Ethers.Contracts.ERC1155.Errors.ERC1155InvalidSender.t/0","type":"type"},{"doc":"Error struct for `error ERC1155MissingApprovalForAll`","ref":"Ethers.Contracts.ERC1155.Errors.ERC1155MissingApprovalForAll.html","title":"Ethers.Contracts.ERC1155.Errors.ERC1155MissingApprovalForAll","type":"module"},{"doc":"","ref":"Ethers.Contracts.ERC1155.Errors.ERC1155MissingApprovalForAll.html#t:t/0","title":"Ethers.Contracts.ERC1155.Errors.ERC1155MissingApprovalForAll.t/0","type":"type"},{"doc":"Error struct for `error ERC20InsufficientAllowance`","ref":"Ethers.Contracts.ERC20.Errors.ERC20InsufficientAllowance.html","title":"Ethers.Contracts.ERC20.Errors.ERC20InsufficientAllowance","type":"module"},{"doc":"","ref":"Ethers.Contracts.ERC20.Errors.ERC20InsufficientAllowance.html#t:t/0","title":"Ethers.Contracts.ERC20.Errors.ERC20InsufficientAllowance.t/0","type":"type"},{"doc":"Error struct for `error ERC20InsufficientBalance`","ref":"Ethers.Contracts.ERC20.Errors.ERC20InsufficientBalance.html","title":"Ethers.Contracts.ERC20.Errors.ERC20InsufficientBalance","type":"module"},{"doc":"","ref":"Ethers.Contracts.ERC20.Errors.ERC20InsufficientBalance.html#t:t/0","title":"Ethers.Contracts.ERC20.Errors.ERC20InsufficientBalance.t/0","type":"type"},{"doc":"Error struct for `error ERC20InvalidApprover`","ref":"Ethers.Contracts.ERC20.Errors.ERC20InvalidApprover.html","title":"Ethers.Contracts.ERC20.Errors.ERC20InvalidApprover","type":"module"},{"doc":"","ref":"Ethers.Contracts.ERC20.Errors.ERC20InvalidApprover.html#t:t/0","title":"Ethers.Contracts.ERC20.Errors.ERC20InvalidApprover.t/0","type":"type"},{"doc":"Error struct for `error ERC20InvalidReceiver`","ref":"Ethers.Contracts.ERC20.Errors.ERC20InvalidReceiver.html","title":"Ethers.Contracts.ERC20.Errors.ERC20InvalidReceiver","type":"module"},{"doc":"","ref":"Ethers.Contracts.ERC20.Errors.ERC20InvalidReceiver.html#t:t/0","title":"Ethers.Contracts.ERC20.Errors.ERC20InvalidReceiver.t/0","type":"type"},{"doc":"Error struct for `error ERC20InvalidSender`","ref":"Ethers.Contracts.ERC20.Errors.ERC20InvalidSender.html","title":"Ethers.Contracts.ERC20.Errors.ERC20InvalidSender","type":"module"},{"doc":"","ref":"Ethers.Contracts.ERC20.Errors.ERC20InvalidSender.html#t:t/0","title":"Ethers.Contracts.ERC20.Errors.ERC20InvalidSender.t/0","type":"type"},{"doc":"Error struct for `error ERC20InvalidSpender`","ref":"Ethers.Contracts.ERC20.Errors.ERC20InvalidSpender.html","title":"Ethers.Contracts.ERC20.Errors.ERC20InvalidSpender","type":"module"},{"doc":"","ref":"Ethers.Contracts.ERC20.Errors.ERC20InvalidSpender.html#t:t/0","title":"Ethers.Contracts.ERC20.Errors.ERC20InvalidSpender.t/0","type":"type"},{"doc":"Error struct for `error ERC721IncorrectOwner`","ref":"Ethers.Contracts.ERC721.Errors.ERC721IncorrectOwner.html","title":"Ethers.Contracts.ERC721.Errors.ERC721IncorrectOwner","type":"module"},{"doc":"","ref":"Ethers.Contracts.ERC721.Errors.ERC721IncorrectOwner.html#t:t/0","title":"Ethers.Contracts.ERC721.Errors.ERC721IncorrectOwner.t/0","type":"type"},{"doc":"Error struct for `error ERC721InsufficientApproval`","ref":"Ethers.Contracts.ERC721.Errors.ERC721InsufficientApproval.html","title":"Ethers.Contracts.ERC721.Errors.ERC721InsufficientApproval","type":"module"},{"doc":"","ref":"Ethers.Contracts.ERC721.Errors.ERC721InsufficientApproval.html#t:t/0","title":"Ethers.Contracts.ERC721.Errors.ERC721InsufficientApproval.t/0","type":"type"},{"doc":"Error struct for `error ERC721InvalidApprover`","ref":"Ethers.Contracts.ERC721.Errors.ERC721InvalidApprover.html","title":"Ethers.Contracts.ERC721.Errors.ERC721InvalidApprover","type":"module"},{"doc":"","ref":"Ethers.Contracts.ERC721.Errors.ERC721InvalidApprover.html#t:t/0","title":"Ethers.Contracts.ERC721.Errors.ERC721InvalidApprover.t/0","type":"type"},{"doc":"Error struct for `error ERC721InvalidOperator`","ref":"Ethers.Contracts.ERC721.Errors.ERC721InvalidOperator.html","title":"Ethers.Contracts.ERC721.Errors.ERC721InvalidOperator","type":"module"},{"doc":"","ref":"Ethers.Contracts.ERC721.Errors.ERC721InvalidOperator.html#t:t/0","title":"Ethers.Contracts.ERC721.Errors.ERC721InvalidOperator.t/0","type":"type"},{"doc":"Error struct for `error ERC721InvalidOwner`","ref":"Ethers.Contracts.ERC721.Errors.ERC721InvalidOwner.html","title":"Ethers.Contracts.ERC721.Errors.ERC721InvalidOwner","type":"module"},{"doc":"","ref":"Ethers.Contracts.ERC721.Errors.ERC721InvalidOwner.html#t:t/0","title":"Ethers.Contracts.ERC721.Errors.ERC721InvalidOwner.t/0","type":"type"},{"doc":"Error struct for `error ERC721InvalidReceiver`","ref":"Ethers.Contracts.ERC721.Errors.ERC721InvalidReceiver.html","title":"Ethers.Contracts.ERC721.Errors.ERC721InvalidReceiver","type":"module"},{"doc":"","ref":"Ethers.Contracts.ERC721.Errors.ERC721InvalidReceiver.html#t:t/0","title":"Ethers.Contracts.ERC721.Errors.ERC721InvalidReceiver.t/0","type":"type"},{"doc":"Error struct for `error ERC721InvalidSender`","ref":"Ethers.Contracts.ERC721.Errors.ERC721InvalidSender.html","title":"Ethers.Contracts.ERC721.Errors.ERC721InvalidSender","type":"module"},{"doc":"","ref":"Ethers.Contracts.ERC721.Errors.ERC721InvalidSender.html#t:t/0","title":"Ethers.Contracts.ERC721.Errors.ERC721InvalidSender.t/0","type":"type"},{"doc":"Error struct for `error ERC721NonexistentToken`","ref":"Ethers.Contracts.ERC721.Errors.ERC721NonexistentToken.html","title":"Ethers.Contracts.ERC721.Errors.ERC721NonexistentToken","type":"module"},{"doc":"","ref":"Ethers.Contracts.ERC721.Errors.ERC721NonexistentToken.html#t:t/0","title":"Ethers.Contracts.ERC721.Errors.ERC721NonexistentToken.t/0","type":"type"},{"doc":"Execution Error Exception.\n\nThe Exception struct will have these values:\n\n- `message`: A string message regarding the exception.\n- `evm_error`: Usually a map containing the error detail returned as is by the RPC server.","ref":"Ethers.ExecutionError.html","title":"Ethers.ExecutionError","type":"exception"},{"doc":"# Elixir Ethers\n\n[![example workflow](https://github.com/ExWeb3/elixir_ethers/actions/workflows/elixir.yml/badge.svg)](https://github.com/ExWeb3/elixir_ethers)\n[![Coverage Status](https://coveralls.io/repos/github/ExWeb3/elixir_ethers/badge.svg?branch=main)](https://coveralls.io/github/ExWeb3/elixir_ethers?branch=main)\n[![Module Version](https://img.shields.io/hexpm/v/ethers.svg)](https://hex.pm/packages/ethers)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/ethers/)\n[![License](https://img.shields.io/hexpm/l/ethers.svg)](https://github.com/ExWeb3/elixir_ethers/blob/master/LICENSE.md)\n[![Last Updated](https://img.shields.io/github/last-commit/ExWeb3/elixir_ethers.svg)](https://github.com/ExWeb3/elixir_ethers/commits/main)\n\nEthers is a comprehensive Web3 library for interacting with smart contracts on the Ethereum (Or any EVM based blockchain) using Elixir.\n\nInspired by [ethers.js](https://github.com/ethers-io/ethers.js/) and [web3.js](https://web3js.readthedocs.io/), Ethers leverages\nElixir's amazing meta-programming capabilities to generate Elixir modules for give smart contracts from their ABI.\nIt also generates beautiful documentation for those modules which can further help developers.","ref":"readme.html","title":"Introduction","type":"extras"},{"doc":"You can install the package by adding `ethers` (and optionally `ex_secp256k1`) to the list of\ndependencies in your `mix.exs` file:\n\n```elixir\ndef deps do\n  [\n    {:ethers, \"~> 0.4.1\"},\n    # Uncomment next line if you want to use local signers\n    # {:ex_secp256k1, \"~> 0.7.2\"}\n  ]\nend\n```\n\nThe complete documentation is available on [hexdocs](https://hexdocs.pm/ethers).","ref":"readme.html#installation","title":"Installation - Introduction","type":"extras"},{"doc":"To use Elixir Ethers, ensure you have a configured JSON-RPC endpoint.\nConfigure the endpoint using the following configuration parameter.\n\n```elixir\n# config.exs\nconfig :ethers,\n  rpc_client: Ethereumex.HttpClient, # Defaults to: Ethereumex.HttpClient\n  keccak_module: ExKeccak, # Defaults to: ExKeccak\n  json_module: Jason, # Defaults to: Jason\n  secp256k1_module: ExSecp256k1, # Defaults to: ExSecp256k1\n  default_signer: nil, # Defaults to: nil, see Ethers.Signer for more info\n  default_signer_opts: [] # Defaults to: []\n\n# If using Ethereumex, you can specify a default JSON-RPC server url here for all requests.\nconfig :ethereumex, url: \"[URL_HERE]\"\n```\n\nYou can use one of the RPC URLs for your chain/wallet of choice or try out one of them from\n[chainlist.org](https://chainlist.org/).\n\nFor more configuration options, refer to\n[ethereumex](https://github.com/mana-ethereum/ethereumex#configuration).\n\nTo send transactions, you need a wallet client capable of signing transactions and exposing a\nJSON-RPC endpoint.","ref":"readme.html#configuration","title":"Configuration - Introduction","type":"extras"},{"doc":"To use Elixir Ethers, you must have your contract's ABI in json format, which can be obtained from\n[etherscan.io](https://etherscan.io). This library also contains standard contract interfaces such\nas `ERC20`, `ERC721` and some more by default (refer to built-in contracts in\n[hexdocs](https://hexdocs.pm/ethers)).\n\nCreate a module for your contract as follows:\n\n```elixir\ndefmodule MyERC20Token do\n  use Ethers.Contract,\n    abi_file: \"path/to/abi.json\",\n    default_address: \"[Contract address here (optional)]\"\n\n  # You can also add more code here in this module if you wish\nend\n```\n\n#","ref":"readme.html#usage","title":"Usage - Introduction","type":"extras"},{"doc":"After defining the module, all the functions can be called like any other Elixir module.\n\nTo fetch the results (return value(s)) of a function you can pass your function result to the\n[`Ethers.call/2`](https://hexdocs.pm/ethers/Ethers.html#call/2) function.\n\n```elixir\n# Calling functions on the blockchain\niex> MyERC20Token.balance_of(\"0x[Address]\") |> Ethers.call()\n{:ok, 654294510138460920346}\n```\n\nRefer to [Ethers.call/2](https://hexdocs.pm/ethers/Ethers.html#call/2) for more information.\n\n#","ref":"readme.html#calling-contract-functions","title":"Calling contract functions - Introduction","type":"extras"},{"doc":"To send transaction (eth_sendTransaction) to the blockchain, you can use the\n[`Ethers.send/2`](https://hexdocs.pm/ethers/Ethers.html#send/2) function.\n\nEnsure that you specify a `from` option to inform your client which account to use as the signer:\n\n```elixir\niex> MyERC20Token.transfer(\"0x[Recipient]\", 1000) |> Ethers.send(from: \"0x[Sender]\")\n{:ok, \"0xf313ff7ff54c6db80ad44c3ad58f72ff0fea7ce88e5e9304991ebd35a6e76000\"}\n```\n\nRefer to [Ethers.send/2](https://hexdocs.pm/ethers/Ethers.html#send/2) for more information.\n\n#","ref":"readme.html#sending-transaction","title":"Sending transaction - Introduction","type":"extras"},{"doc":"Ethers provides functionality for creating event filters and fetching related events from the\nblockchain. Each contract generated by Ethers also will have `EventFilters` module\n(e.g. `MyERC20Token.EventFilter`s) that can be used to create filters for events.\n\nTo create an event filter and then use\n[`Ethers.get_logs/2`](https://hexdocs.pm/ethers/Ethers.html#get_logs/2) function like the below\nexample.\n\n```elixir\n# Create The Event Filter\n# (`nil` can be used for a parameter in EventFilters functions to indicate no filtering)\niex> filter = MyERC20Token.EventFilters.transfer(\"0x[From Address Here]\", nil)\n\n# Then you can simply list the logs using `Ethers.get_logs/2`\n\niex> Ethers.get_logs(filter)\n{:ok,\n [\n   %Ethers.Event{\n     address: \"0x5883c66ca442461d406f330775d42954bfcf7d92\",\n     block_hash: \"0x83de67fd285067b838790406ea68f21a3afbc0ade534047725b5ccfb904c9ed3\",\n     block_number: 17077047,\n     topics: [\"Transfer(address,address,uint256)\",\n      \"0x6b75d8af000000e20b7a7ddf000ba900b4009a80\",\n      \"0x230507f6a391ae5ac0ec124f1c5b8ce454fe3f3d\"],\n     topics_raw: [\"0xddf252ad1be2c89b69c2b068fc378daa952ba7f163c4a11628f55a4df523b3ef\",\n      \"0x0000000000000000000000006b75d8af000000e20b7a7ddf000ba900b4009a80\",\n      \"0x000000000000000000000000230507f6a391ae5ac0ec124f1c5b8ce454fe3f3d\"],\n     transaction_hash: \"0xaa6fb2e1bbb27f667e76b03e8cde23db694207e06b9aa810d4c20c1f109a58e5\",\n     transaction_index: 0,\n     data: [761112156078097834180608],\n     log_index: 0,\n     removed: false\n   },\n   %Ethers.Event{...},\n    ...\n ]}\n```\n\n#","ref":"readme.html#getting-logs-events","title":"Getting Logs (Events) - Introduction","type":"extras"},{"doc":"To resolve ENS or any other name service provider (which are ENS compatible) in the blockchain\nyou can simply use [`Ethers.NameService`](https://hexdocs.pm/ethers/Ethers.NameService.html) module.\n\n```elixir\niex> Ethers.NameService.resolve(\"vitalik.eth\")\n{:ok, \"0xd8da6bf26964af9d7eed9e03e53415d37aa96045\"}\n```\n\n#","ref":"readme.html#resolving-ethereum-names-ens-domains-using-ethers","title":"Resolving Ethereum names (ENS domains) using Ethers - Introduction","type":"extras"},{"doc":"Ethers already includes some of the well-known contract interface standards for you to use.\nHere is a list of them.\n\n- [ERC20](https://hexdocs.pm/ethers/Ethers.Contracts.ERC20.html) - The well know fungible token standard\n- [ERC721](https://hexdocs.pm/ethers/Ethers.Contracts.ERC721.html) - Non-Fungible tokens (NFTs) standard\n- [ERC777](https://hexdocs.pm/ethers/Ethers.Contracts.ERC777.html) - Improved fungible token standard\n- [ERC1155](https://hexdocs.pm/ethers/Ethers.Contracts.ERC1155.html) - Multi-Token standard (Fungible, Non-Fungible or Semi-Fungible)\n- [Multicall](https://hexdocs.pm/ethers/Ethers.Multicall.html) - [Multicall3](https://www.multicall3.com/)\n\nTo use them you just need to specify the target contract address (`:to` option) of your token and\ncall the functions. Example:\n\n```elixir\niex> tx_data = Ethers.Contracts.ERC20.balance_of(\"0x[Holder Address]\")\n#Ethers.TxData \n\niex> Ethers.call(tx_data, to: \"0x[Token Address]\")\n{:ok, 123456}\n```","ref":"readme.html#built-in-contract-interfaces-in-ethers","title":"Built-in contract interfaces in Ethers - Introduction","type":"extras"},{"doc":"For a detailed documentation visit [Ethers hexdocs page](https://hexdocs.pm/ethers).\n\n#","ref":"readme.html#documentation","title":"Documentation - Introduction","type":"extras"},{"doc":"Ethers generates documentation for all the functions and event filters based on the ABI data.\nTo get the documentation you can either use the `h/1` IEx helper function or generate HTML/epub\ndocs using ExDoc.\n\n##","ref":"readme.html#generated-documentation-for-functions-and-event-filters","title":"Generated documentation for functions and event filters - Introduction","type":"extras"},{"doc":"```elixir\niex(3)> h MyERC20Token.balance_of\n\n                             def balance_of(owner)\n\n  @spec balance_of(Ethers.Types.t_address()) :: Ethers.TxData.t()\n\nPrepares balanceOf(address _owner) call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on\nits own. (Use Ethers.call/2)\n\nState mutability: view","ref":"readme.html#get-the-documentation-of-a-contract-function","title":"Get the documentation of a contract function - Introduction","type":"extras"},{"doc":"• _owner: `:address`","ref":"readme.html#function-parameter-types","title":"Function Parameter Types - Introduction","type":"extras"},{"doc":"• balance: {:uint, 256}\n```\n\n##","ref":"readme.html#return-types-when-called-with-ethers-call-2","title":"Return Types (when called with `Ethers.call/2`) - Introduction","type":"extras"},{"doc":"One cool and potentially useful feature of Ethers is how you can inspect the call\n\n##","ref":"readme.html#inspecting-txdata-and-eventfilter-structs","title":"Inspecting TxData and EventFilter structs - Introduction","type":"extras"},{"doc":"```elixir\niex(4)> h MyERC20Token.EventFilters.transfer\n\n                             def transfer(from, to)\n\n  @spec transfer(Ethers.Types.t_address(), Ethers.Types.t_address()) ::\n          Ethers.EventFilter.t()\n\nCreate event filter for Transfer(address from, address to, uint256 value)\n\nFor each indexed parameter you can either pass in the value you want to filter\nor nil if you don't want to filter.","ref":"readme.html#get-the-documentation-of-a-event-filter","title":"Get the documentation of a event filter - Introduction","type":"extras"},{"doc":"• from: :address\n  • to: :address","ref":"readme.html#parameter-types-event-indexed-topics","title":"Parameter Types (Event indexed topics) - Introduction","type":"extras"},{"doc":"These are non-indexed topics (often referred to as data) of the event log.\n\n  • value: {:uint, 256}\n```","ref":"readme.html#event-data-types-when-called-with-ethers-get_logs-2","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Introduction","type":"extras"},{"doc":"By default, Ethers will rely on the default blockchain endpoint to handle the signing (using `eth_sendTransaction` RPC function). Obviously public endpoints cannot help you with signing the transactions since they do not hold your private keys.\n\nTo sign transactions on Ethers, You can specify a `signer` module when sending/signing transactions. A signer module is a module which implements the [Ethers.Signer](lib/ethers/signer.ex) behaviour.\n\nEthers has these built-in signers to use:\n\n- `Ethers.Signer.Local`: A local signer which loads a private key from `signer_opts` and signs the transactions.\n- `Ethers.Signer.JsonRPC`: Uses `eth_signTransaction` Json RPC function to sign transactions. (Using services like [Consensys/web3signer](https://github.com/Consensys/web3signer) or [geth](https://geth.ethereum.org/))\n\nFor more information on signers, visit [hexdocs](https://hexdocs.pm/ethers/Ethers.Signer.html).\n\n#","ref":"readme.html#signing-transactions","title":"Signing Transactions - Introduction","type":"extras"},{"doc":"```elixir\nMyERC20Token.transfer(\"0x[Recipient]\", 1000)\n|> Ethers.send(\n  from: \"0x[Sender]\",\n  signer: Ethers.Signer.Local,\n  signer_opts: [private_key: \"0x...\"]\n)\n```","ref":"readme.html#example","title":"Example - Introduction","type":"extras"},{"doc":"All contributions are very welcome (as simple as fixing typos). Please feel free to open issues and\npush Pull Requests. Just remember to be respectful to everyone!\n\nTo run the tests locally, follow below steps:\n\n- Install [ethereum](https://geth.ethereum.org/docs/getting-started/installing-geth) and [solc](https://docs.soliditylang.org/en/latest/installing-solidity.html). For example, on MacOS\n\n```\nbrew install ethereum\nnpm install -g solc\n```\n\n- Run [ganache](https://github.com/trufflesuite/ganache).\n  After installing ganache, just run the following in a new window\n\n```\n> ganache --wallet.deterministic\n```\n\nThen you should be able to run tests through `mix test`.","ref":"readme.html#contributing","title":"Contributing - Introduction","type":"extras"},{"doc":"Ethers was possible to make thanks to the great contributors of the following libraries.\n\n- [ABI](https://github.com/poanetwork/ex_abi)\n- [Ethereumex](https://github.com/mana-ethereum/ethereumex)\n- [ExKeccak](https://github.com/tzumby/ex_keccak)\n\nAnd also all the people who contributed to this project in any ways.","ref":"readme.html#acknowledgements","title":"Acknowledgements - Introduction","type":"extras"},{"doc":"[Apache License 2.0](https://github.com/ExWeb3/elixir_ethers/blob/main/LICENSE)","ref":"readme.html#license","title":"License - Introduction","type":"extras"},{"doc":"# Changelog","ref":"changelog.html","title":"Changelog","type":"extras"},{"doc":"#","ref":"changelog.html#v0-4-1-2024-04-02","title":"v0.4.1 (2024-04-02) - Changelog","type":"extras"},{"doc":"- Add support of getting current `max_priority_fee_per_gas`\n- Use latest `max_priority_fee_per_gas` from the chain as default value in transactions","ref":"changelog.html#enhancements","title":"Enhancements - Changelog","type":"extras"},{"doc":"#","ref":"changelog.html#v0-4-0-2024-03-11","title":"v0.4.0 (2024-03-11) - Changelog","type":"extras"},{"doc":"- Custom errors will be returned as error structs instead of raw RPC response\n- Updated ERC20, ERC721 and ERC1155 ABIs to Openzeppelin 5.x\n\n#","ref":"changelog.html#breaking-changes","title":"Breaking Changes - Changelog","type":"extras"},{"doc":"- Generate error structs from ABI and decode custom errors when error data is available\n- Use JsonRPC signer as a default signer in `Ethers.sign_transaction/2`","ref":"changelog.html#enhancements","title":"Enhancements - Changelog","type":"extras"},{"doc":"#","ref":"changelog.html#v0-3-1-2024-03-05","title":"v0.3.1 (2024-03-05) - Changelog","type":"extras"},{"doc":"- Fix trimmed zeros in transaction encoder with unified hex encoding for transaction","ref":"changelog.html#bug-fixes","title":"Bug fixes - Changelog","type":"extras"},{"doc":"#","ref":"changelog.html#v0-3-0-2024-02-05","title":"v0.3.0 (2024-02-05) - Changelog","type":"extras"},{"doc":"- Removed `signature_v`, `signature_recovery_id` and `signature_y_parity` from `Ethers.Transaction`\n  struct and introduce new `signature_v_or_y_parity` value\n- Update `ex_abi` to 0.7.0 with new `method_id` logic for event selectors and use its value\n\n#","ref":"changelog.html#breaking-changes","title":"Breaking Changes - Changelog","type":"extras"},{"doc":"- Cleanup implementation of Transaction encoders and value decoder","ref":"changelog.html#enhancements","title":"Enhancements - Changelog","type":"extras"},{"doc":"#","ref":"changelog.html#v0-2-3-2024-01-29","title":"v0.2.3 (2024-01-29) - Changelog","type":"extras"},{"doc":"- Add `Ethers.get_transaction_receipt/2` function to query native chain transaction receipt by transaction hash.\n\n#","ref":"changelog.html#new-features","title":"New features - Changelog","type":"extras"},{"doc":"- Add more metadata to `Ethers.Transaction` struct.\n- Return `Ethers.Transaction` struct in `Ethers.get_transaction/2` function.\n- Support `get_transaction` in batch requests.","ref":"changelog.html#enhancements","title":"Enhancements - Changelog","type":"extras"},{"doc":"#","ref":"changelog.html#v0-2-2-2024-01-08","title":"v0.2.2 (2024-01-08) - Changelog","type":"extras"},{"doc":"- Add `Ethers.get_transaction/2` function to query native chain transaction by transaction hash.","ref":"changelog.html#new-features","title":"New features - Changelog","type":"extras"},{"doc":"#","ref":"changelog.html#v0-2-1-2024-01-04","title":"v0.2.1 (2024-01-04) - Changelog","type":"extras"},{"doc":"- Add `Ethers.get_balance/2` function to query native chain balance of accounts.\n\n#","ref":"changelog.html#new-features","title":"New features - Changelog","type":"extras"},{"doc":"- Encode integers to hex even when they are part of params","ref":"changelog.html#bug-fixes","title":"Bug fixes - Changelog","type":"extras"},{"doc":"#","ref":"changelog.html#v0-2-0-2024-01-01","title":"v0.2.0 (2024-01-01) - Changelog","type":"extras"},{"doc":"- `Ethers.sign_transaction/2` function\n- Signer behaviour\n- Local Signer implementation\n- JsonRPC Signer implementation\n- `Ethers.Transaction` struct and helper functions","ref":"changelog.html#new-features","title":"New Features - Changelog","type":"extras"},{"doc":"#","ref":"changelog.html#v0-1-3-2023-12-26","title":"v0.1.3 (2023-12-26) - Changelog","type":"extras"},{"doc":"- unsized integer encoding to hex will now raise if given negative numbers.\n- `Utils.date_to_block_number/3` going to negative block numbers issue fixed.","ref":"changelog.html#bug-fixes","title":"Bug fixes - Changelog","type":"extras"},{"doc":"#","ref":"changelog.html#v0-1-2-2023-12-12","title":"v0.1.2 (2023-12-12) - Changelog","type":"extras"},{"doc":"- `TxData.to_map/2` now returns hex values for all integers.\n- `Utils.maybe_add_gas_limit/2` now adds hex gas limit value instead of integer.","ref":"changelog.html#breaking-changes","title":"Breaking Changes - Changelog","type":"extras"},{"doc":"#","ref":"changelog.html#v0-1-1-2023-11-22","title":"v0.1.1 (2023-11-22) - Changelog","type":"extras"},{"doc":"- Multicall: aggregate_3 decoder returns `nil` in case of failure\n- Multicall: Feed decoded results through `Utils.human_arg/2`","ref":"changelog.html#bug-fixes","title":"Bug fixes - Changelog","type":"extras"},{"doc":"#","ref":"changelog.html#v0-1-0-2023-11-19","title":"v0.1.0 (2023-11-19) - Changelog","type":"extras"},{"doc":"- Checksum address utility functions\n\n#","ref":"changelog.html#new-features","title":"New Features - Changelog","type":"extras"},{"doc":"- Use zip_reduce for event generators\n- Move documentation generators to ContractHelpers\n- Display message for empty parameters or return types\n- `Ethers.call/2` and `Ethers.get_logs/2` now automatically convert integer block numbers to hex values\n- Return structs as a result in generated functions and event filter with Inspection protocols implemented for better development experience\n- Support dynamically sized indexed event filters (bytes, strings, arrays and structs)\n- `Ethers.call/2` now only returns as a list if the return type is either a solidity array or tuple\n- Add return names in documentations and TxData inspection\n- Added an interface for `Multicall3` through `Ethers.Contracts.Multicall3`\n- Added `Ethers.Multicall` as an abstraction for `Ethers.Contracts.Multicall3`\n- Added batching functionality using `Ethers.batch/2`\n\n#","ref":"changelog.html#enhancements","title":"Enhancements - Changelog","type":"extras"},{"doc":"- The generated contract functions no longer call or send transactions, They will only prepare parameters\n  To execute an explicit call to `Ethers.send/2` or `Ethers.call/2` is required\n- Events no longer accept `address` overrides. Overriding now happens at `Ethers.get_logs/2`\n- Function `Ethers.get_logs/3` is now changed to `Ethers.get_logs/2`\n- Generated contract modules and EventFilter modules `default_address/0` function is now renamed to `__default_adress__/0` to prevent collision\n- Removal of `Ethers.RPC` module\n- Remove `Ethers.Types.dynamically_sized_types/0` function\n- `Ethers.call/2` response is not always a list\n- `Ethers.deploy/4` is now removed and replaced with `Ethers.deploy/2`\n\n#","ref":"changelog.html#breaking-changes","title":"Breaking Changes - Changelog","type":"extras"},{"doc":"- Fix event filters with mixed indexed and non-indexed arguments","ref":"changelog.html#bug-fixes","title":"Bug fixes - Changelog","type":"extras"},{"doc":"#","ref":"changelog.html#v0-0-6-2023-09-06","title":"v0.0.6 (2023-09-06) - Changelog","type":"extras"},{"doc":"- Update `dialyxir` dependency to 1.4.0\n- Update `ex_doc` to 0.30.6\n- Add more function to `Utils` module\n- Improve failure return values of deployment functions\n\n#","ref":"changelog.html#enhancements","title":"Enhancements - Changelog","type":"extras"},{"doc":"- Fix RPC options and client override issue\n- Do not add `nil` to address when address is not present","ref":"changelog.html#bug-fixes","title":"Bug fixes - Changelog","type":"extras"},{"doc":"#","ref":"changelog.html#v0-0-5-2023-08-21","title":"v0.0.5 (2023-08-21) - Changelog","type":"extras"},{"doc":"- Add ENS (Ethereum name service) contracts and helper functions\n- Update `ex_doc` dependency to 0.30.4\n- Address `Logger.warn` deprecation","ref":"changelog.html#enhancements","title":"Enhancements - Changelog","type":"extras"},{"doc":"#","ref":"changelog.html#v0-0-4-2023-07-14","title":"v0.0.4 (2023-07-14) - Changelog","type":"extras"},{"doc":"- Update `ex_doc` dependency to 0.30.1\n- Update `jason` dependency to 1.4.1","ref":"changelog.html#enhancements","title":"Enhancements - Changelog","type":"extras"},{"doc":"#","ref":"changelog.html#v0-0-3-2023-05-29","title":"v0.0.3 (2023-05-29) - Changelog","type":"extras"},{"doc":"- Improved generative documentation for modules\n- Improved gas estimation API\n- Add gas limit to sending trasnactions\n- Remove redundant gas estimation function\n\n#","ref":"changelog.html#enhancements","title":"Enhancements - Changelog","type":"extras"},{"doc":"- Fix bitsize check guard to include all available solidity bitsizes","ref":"changelog.html#bug-fixes","title":"Bug fixes - Changelog","type":"extras"},{"doc":"#","ref":"changelog.html#v0-0-2-2023-04-24","title":"v0.0.2 (2023-04-24) - Changelog","type":"extras"},{"doc":"- Include the priv directory in mix releases","ref":"changelog.html#bug-fixes","title":"Bug fixes - Changelog","type":"extras"},{"doc":"First Release","ref":"changelog.html#v0-0-1-2023-04-24","title":"v0.0.1 (2023-04-24) - Changelog","type":"extras"},{"doc":"# Typed Arguments\n\nTyped arguments help Ethers with determining the exact function to use when there are multiple overloads of\nthe same function with same arity.","ref":"typed-arguments.html","title":"Typed Arguments","type":"extras"},{"doc":"In solidity, contract functions (and events) can be overloaded.\nThis means a function with the same name can be defined with different argument types and even different arities.\n\n#","ref":"typed-arguments.html#problem","title":"Problem - Typed Arguments","type":"extras"},{"doc":"```solidity\ncontract Overloaded {\n    function transfer(uint256 amount) public pure returns (string memory) {\n        ...\n    }\n\n    function transfer(int256 amount) public pure returns (string memory) {\n        ...\n    }\n}\n```\n\nIn the above contract, the function transfer is once implemented with `uint256` and another time with `int256`.\n\nSince Elixir is dynamically typed, we need a way to specify which function we need to call in this scenario.","ref":"typed-arguments.html#example","title":"Example - Typed Arguments","type":"extras"},{"doc":"Ethers provides a simple helper function called `Ethers.Types.typed/2`. This function helps you with specifying the type for your parameter. It will help Ethers to know which function to select when you want to call it.\n\nLet's try it with the example contract above. If we assume we want to call the transfer function with `uint256` type, here is the code we need.\n\n```elixir\ndefmodule Overloaded do\n  use Ethers.Contract, abi: ...\nend\n\nOverloaded.transfer(Ethers.Types.typed({:uint, 256}, 100))\n|> Ethers.send!(...)\n```\n\nThis way we have explicitly told Ethers to use the `uint256` type for the first argument.","ref":"typed-arguments.html#solution","title":"Solution - Typed Arguments","type":"extras"},{"doc":"Ethers supports all generic data types from EVM. Here is a list of them.\n\n| Elixir Type              | Solidity Type     | Description                                         |\n| ------------------------ | ----------------- | --------------------------------------------------- |\n| `:address`               | `address`         | Ethereum wallet address                             |\n| `:bool`                  | `bool`            | Boolean value                                       |\n| `:string`                | `string`          | Dynamic length string                               |\n| `:bytes`                 | `bytes`           | Dynamic length byte array [^1]                      | \n| `{:bytes, size}`         | `bytes{size}`     | Fixed length byte array [^1]                        | \n| `{:uint, bitsize}`       | `uint{bitsize}`   | Unsigned integer [^2]                               |\n| `{:int, bitsize}`        | `int{bitsize}`    | Signed integer  [^2]                                |\n| `{:array, type}`         | `T[]`             | Dynamic length array of type                        |\n| `{:array, type, length}` | `T[{length}]`     | Fixed length array of type                          |\n| `{:tuple, types}`        | Tuples or Structs | A tuple with types (structs in solidity are tuples) |\n\n[^1]: For fixed length byte array (bytes1, bytes2, ..., bytes32) the size must be between 1 and 32.\n[^2]: For `int` and `uint` data types, the bitsize must be between 8 and 256 and also dividable to 8.","ref":"typed-arguments.html#supported-types","title":"Supported Types - Typed Arguments","type":"extras"}],"producer":{"name":"ex_doc","version":[48,46,51,49,46,50]}}